You can subscribe to this list here.
| 2002 |
Jan
|
Feb
|
Mar
|
Apr
|
May
|
Jun
|
Jul
|
Aug
|
Sep
(1) |
Oct
(122) |
Nov
(152) |
Dec
(69) |
|---|---|---|---|---|---|---|---|---|---|---|---|---|
| 2003 |
Jan
(6) |
Feb
(25) |
Mar
(73) |
Apr
(82) |
May
(24) |
Jun
(25) |
Jul
(10) |
Aug
(11) |
Sep
(10) |
Oct
(54) |
Nov
(203) |
Dec
(182) |
| 2004 |
Jan
(307) |
Feb
(305) |
Mar
(430) |
Apr
(312) |
May
(187) |
Jun
(342) |
Jul
(487) |
Aug
(637) |
Sep
(336) |
Oct
(373) |
Nov
(441) |
Dec
(210) |
| 2005 |
Jan
(385) |
Feb
(480) |
Mar
(636) |
Apr
(544) |
May
(679) |
Jun
(625) |
Jul
(810) |
Aug
(838) |
Sep
(634) |
Oct
(521) |
Nov
(965) |
Dec
(543) |
| 2006 |
Jan
(494) |
Feb
(431) |
Mar
(546) |
Apr
(411) |
May
(406) |
Jun
(322) |
Jul
(256) |
Aug
(401) |
Sep
(345) |
Oct
(542) |
Nov
(308) |
Dec
(481) |
| 2007 |
Jan
(427) |
Feb
(326) |
Mar
(367) |
Apr
(255) |
May
(244) |
Jun
(204) |
Jul
(223) |
Aug
(231) |
Sep
(354) |
Oct
(374) |
Nov
(497) |
Dec
(362) |
| 2008 |
Jan
(322) |
Feb
(482) |
Mar
(658) |
Apr
(422) |
May
(476) |
Jun
(396) |
Jul
(455) |
Aug
(267) |
Sep
(280) |
Oct
(253) |
Nov
(232) |
Dec
(304) |
| 2009 |
Jan
(486) |
Feb
(470) |
Mar
(458) |
Apr
(423) |
May
(696) |
Jun
(461) |
Jul
(551) |
Aug
(575) |
Sep
(134) |
Oct
(110) |
Nov
(157) |
Dec
(102) |
| 2010 |
Jan
(226) |
Feb
(86) |
Mar
(147) |
Apr
(117) |
May
(107) |
Jun
(203) |
Jul
(193) |
Aug
(238) |
Sep
(300) |
Oct
(246) |
Nov
(23) |
Dec
(75) |
| 2011 |
Jan
(133) |
Feb
(195) |
Mar
(315) |
Apr
(200) |
May
(267) |
Jun
(293) |
Jul
(353) |
Aug
(237) |
Sep
(278) |
Oct
(611) |
Nov
(274) |
Dec
(260) |
| 2012 |
Jan
(303) |
Feb
(391) |
Mar
(417) |
Apr
(441) |
May
(488) |
Jun
(655) |
Jul
(590) |
Aug
(610) |
Sep
(526) |
Oct
(478) |
Nov
(359) |
Dec
(372) |
| 2013 |
Jan
(467) |
Feb
(226) |
Mar
(391) |
Apr
(281) |
May
(299) |
Jun
(252) |
Jul
(311) |
Aug
(352) |
Sep
(481) |
Oct
(571) |
Nov
(222) |
Dec
(231) |
| 2014 |
Jan
(185) |
Feb
(329) |
Mar
(245) |
Apr
(238) |
May
(281) |
Jun
(399) |
Jul
(382) |
Aug
(500) |
Sep
(579) |
Oct
(435) |
Nov
(487) |
Dec
(256) |
| 2015 |
Jan
(338) |
Feb
(357) |
Mar
(330) |
Apr
(294) |
May
(191) |
Jun
(108) |
Jul
(142) |
Aug
(261) |
Sep
(190) |
Oct
(54) |
Nov
(83) |
Dec
(22) |
| 2016 |
Jan
(49) |
Feb
(89) |
Mar
(33) |
Apr
(50) |
May
(27) |
Jun
(34) |
Jul
(53) |
Aug
(53) |
Sep
(98) |
Oct
(206) |
Nov
(93) |
Dec
(53) |
| 2017 |
Jan
(65) |
Feb
(82) |
Mar
(102) |
Apr
(86) |
May
(187) |
Jun
(67) |
Jul
(23) |
Aug
(93) |
Sep
(65) |
Oct
(45) |
Nov
(35) |
Dec
(17) |
| 2018 |
Jan
(26) |
Feb
(35) |
Mar
(38) |
Apr
(32) |
May
(8) |
Jun
(43) |
Jul
(27) |
Aug
(30) |
Sep
(43) |
Oct
(42) |
Nov
(38) |
Dec
(67) |
| 2019 |
Jan
(32) |
Feb
(37) |
Mar
(53) |
Apr
(64) |
May
(49) |
Jun
(18) |
Jul
(14) |
Aug
(53) |
Sep
(25) |
Oct
(30) |
Nov
(49) |
Dec
(31) |
| 2020 |
Jan
(87) |
Feb
(45) |
Mar
(37) |
Apr
(51) |
May
(99) |
Jun
(36) |
Jul
(11) |
Aug
(14) |
Sep
(20) |
Oct
(24) |
Nov
(40) |
Dec
(23) |
| 2021 |
Jan
(14) |
Feb
(53) |
Mar
(85) |
Apr
(15) |
May
(19) |
Jun
(3) |
Jul
(14) |
Aug
(1) |
Sep
(57) |
Oct
(73) |
Nov
(56) |
Dec
(22) |
| 2022 |
Jan
(3) |
Feb
(22) |
Mar
(6) |
Apr
(55) |
May
(46) |
Jun
(39) |
Jul
(15) |
Aug
(9) |
Sep
(11) |
Oct
(34) |
Nov
(20) |
Dec
(36) |
| 2023 |
Jan
(79) |
Feb
(41) |
Mar
(99) |
Apr
(169) |
May
(48) |
Jun
(16) |
Jul
(16) |
Aug
(57) |
Sep
(19) |
Oct
|
Nov
|
Dec
|
| S | M | T | W | T | F | S |
|---|---|---|---|---|---|---|
|
|
|
|
|
|
|
1
(12) |
|
2
(6) |
3
(13) |
4
(9) |
5
(6) |
6
(8) |
7
(5) |
8
(5) |
|
9
(15) |
10
(18) |
11
(18) |
12
(18) |
13
(7) |
14
(11) |
15
(6) |
|
16
(12) |
17
(28) |
18
(15) |
19
(12) |
20
(17) |
21
(23) |
22
(10) |
|
23
(9) |
24
(11) |
25
(7) |
26
(21) |
27
(12) |
28
(6) |
29
(6) |
|
30
(8) |
|
|
|
|
|
|
|
From: <sv...@va...> - 2007-09-19 22:46:16
|
Author: njn
Date: 2007-09-19 23:46:18 +0100 (Wed, 19 Sep 2007)
New Revision: 6869
Log:
Fix bug in -v printing.
Modified:
branches/MASSIF2/massif/ms_main.c
Modified: branches/MASSIF2/massif/ms_main.c
===================================================================
--- branches/MASSIF2/massif/ms_main.c 2007-09-19 22:36:29 UTC (rev 6868)
+++ branches/MASSIF2/massif/ms_main.c 2007-09-19 22:46:18 UTC (rev 6869)
@@ -33,6 +33,9 @@
// Todo:
// - write a good basic test that shows how the tool works, suitable for
// documentation
+// - try to write a -v test. how to filter the Valgrind -v stuff out? Have
+// --ms-verbose, which is implied by -v but also able to be turned on
+// separately?
// - get snapshot frequency right after some have been discarded
// - Check MALLOCLIKE_BLOCK works, write regtest
// - clean up structure of ms_print
@@ -411,6 +414,15 @@
typedef enum { TimeMS, TimeB } TimeUnit;
+static Char* TimeUnit_to_string(TimeUnit time_unit)
+{
+ switch (time_unit) {
+ case TimeMS: return "ms";
+ case TimeB: return "B";
+ default: tl_assert2(0, "TimeUnit_to_string: unrecognised TimeUnit");
+ }
+}
+
static Bool clo_heap = True;
static UInt clo_heap_admin = 8;
static Bool clo_stacks = True;
@@ -1070,6 +1082,7 @@
// for a while -- that would just give N snapshots at almost the same time.
if (VG_(clo_verbosity) > 1) {
VG_(message)(Vg_DebugMsg, "snapshot: %d %s (took %d ms)", time_ms,
+ TimeUnit_to_string(clo_time_unit),
VG_(read_millisecond_timer)() - time_ms );
}
time_of_prev_snapshot = time;
@@ -1549,10 +1562,7 @@
}
FP("\n");
- FP("time_unit: ");
- if (clo_time_unit == TimeMS) FP("ms\n");
- else if (clo_time_unit == TimeB) FP("B\n");
- else tl_assert2(0, "bad --time-unit value");
+ FP("time_unit: %s\n", TimeUnit_to_string(clo_time_unit));
for (i = 0; i < next_snapshot; i++) {
Snapshot* snapshot = & snapshots[i];
|
|
From: <sv...@va...> - 2007-09-19 22:37:11
|
Author: njn
Date: 2007-09-19 23:36:29 +0100 (Wed, 19 Sep 2007)
New Revision: 6868
Log:
- Add two tests that test --alloc-fns
- Clean up massif.out after toobig-allocs
Added:
branches/MASSIF2/massif/tests/alloc-fns-A.post.exp
branches/MASSIF2/massif/tests/alloc-fns-A.stderr.exp
branches/MASSIF2/massif/tests/alloc-fns-A.vgtest
branches/MASSIF2/massif/tests/alloc-fns-B.post.exp
branches/MASSIF2/massif/tests/alloc-fns-B.stderr.exp
branches/MASSIF2/massif/tests/alloc-fns-B.vgtest
branches/MASSIF2/massif/tests/alloc-fns.c
Modified:
branches/MASSIF2/massif/tests/Makefile.am
branches/MASSIF2/massif/tests/toobig-allocs.vgtest
Modified: branches/MASSIF2/massif/tests/Makefile.am
===================================================================
--- branches/MASSIF2/massif/tests/Makefile.am 2007-09-19 08:11:49 UTC (rev 6867)
+++ branches/MASSIF2/massif/tests/Makefile.am 2007-09-19 22:36:29 UTC (rev 6868)
@@ -5,6 +5,8 @@
noinst_SCRIPTS = filter_stderr
EXTRA_DIST = $(noinst_SCRIPTS) \
+ alloc-fns-A.post.exp alloc-fns-A.stderr.exp alloc-fns-A.vgtest \
+ alloc-fns-B.post.exp alloc-fns-B.stderr.exp alloc-fns-B.vgtest \
basic.post.exp basic.stderr.exp basic.vgtest \
basic_malloc.stderr.exp basic_malloc.vgtest \
thresholds_0_0.post.exp thresholds_0_0.stderr.exp thresholds_0_0.vgtest \
@@ -18,6 +20,7 @@
AM_CFLAGS = $(WERROR) -Winline -Wall -Wshadow -g $(AM_FLAG_M3264_PRI)
check_PROGRAMS = \
+ alloc-fns \
basic \
basic_malloc \
thresholds
Added: branches/MASSIF2/massif/tests/alloc-fns-A.post.exp
===================================================================
--- branches/MASSIF2/massif/tests/alloc-fns-A.post.exp (rev 0)
+++ branches/MASSIF2/massif/tests/alloc-fns-A.post.exp 2007-09-19 22:36:29 UTC (rev 6868)
@@ -0,0 +1,83 @@
+--------------------------------------------------------------------------------
+Command: ./alloc-fns
+Data file: massif.out
+Options: XXX
+--------------------------------------------------------------------------------
+
+
+900 | @
+ | @
+ | . @
+ | : @
+ | . : @
+ | : : @
+ | : : @
+ | : : : @
+ | : : : @
+ | : : : : @
+ | : : : : @
+ | . : : : : @
+ | : : : : : @
+ | . : : : : : @
+ | : : : : : : @
+ | : : : : : : @
+ | : : : : : : : @
+ | : : : : : : : @
+ | : : : : : : : : @
+ | : : : : : : : : @
+ 0 +-----------------------------------------------------------------------@
+
+
+Number of snapshots: 10
+ Detailed snapshots: [9]
+--------------------------------------------------------------------------------
+ n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
+--------------------------------------------------------------------------------
+ 0 0 0 0 0 0
+ 1 100 100 100 0 0
+ 2 200 200 200 0 0
+ 3 300 300 300 0 0
+ 4 400 400 400 0 0
+ 5 500 500 500 0 0
+ 6 600 600 600 0 0
+ 7 700 700 700 0 0
+ 8 800 800 800 0 0
+ 9 900 900 900 0 0
+100.00% (900B) (heap allocation functions) malloc/new/new[], --alloc-fns, etc.
+->44.44% (400B) 0x8048498: d4 (alloc-fns.c:18)
+| ->33.33% (300B) 0x80484AE: d3 (alloc-fns.c:19)
+| | ->22.22% (200B) 0x80484C4: d2 (alloc-fns.c:20)
+| | | ->11.11% (100B) 0x80484DA: d1 (alloc-fns.c:21)
+| | | | ->11.11% (100B) 0x8048546: main (alloc-fns.c:30)
+| | | |
+| | | ->11.11% (100B) 0x8048553: main (alloc-fns.c:31)
+| | |
+| | ->11.11% (100B) 0x8048560: main (alloc-fns.c:32)
+| |
+| ->11.11% (100B) 0x804856D: main (alloc-fns.c:33)
+|
+->33.33% (300B) 0x804838D: a4 (alloc-fns.c:3)
+| ->33.33% (300B) 0x80483A3: a3 (alloc-fns.c:4)
+| ->33.33% (300B) 0x80483B9: a2 (alloc-fns.c:5)
+| ->33.33% (300B) 0x80483CF: a1 (alloc-fns.c:6)
+| ->11.11% (100B) 0x8048505: main (alloc-fns.c:25)
+| |
+| ->11.11% (100B) 0x8048512: main (alloc-fns.c:26)
+| |
+| ->11.11% (100B) 0x804851F: main (alloc-fns.c:27)
+|
+->11.11% (100B) 0x80483E6: b4 (alloc-fns.c:8)
+| ->11.11% (100B) 0x80483FC: b3 (alloc-fns.c:9)
+| ->11.11% (100B) 0x8048412: b2 (alloc-fns.c:10)
+| ->11.11% (100B) 0x8048428: b1 (alloc-fns.c:11)
+| ->11.11% (100B) 0x804852C: main (alloc-fns.c:28)
+|
+->11.11% (100B) 0x804843F: c4 (alloc-fns.c:13)
+ ->11.11% (100B) 0x8048455: c3 (alloc-fns.c:14)
+ ->11.11% (100B) 0x804846B: c2 (alloc-fns.c:15)
+ ->11.11% (100B) 0x8048481: c1 (alloc-fns.c:16)
+ ->11.11% (100B) 0x8048539: main (alloc-fns.c:29)
+
+--------------------------------------------------------------------------------
+ n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
+--------------------------------------------------------------------------------
Added: branches/MASSIF2/massif/tests/alloc-fns-A.stderr.exp
===================================================================
--- branches/MASSIF2/massif/tests/alloc-fns-A.stderr.exp (rev 0)
+++ branches/MASSIF2/massif/tests/alloc-fns-A.stderr.exp 2007-09-19 22:36:29 UTC (rev 6868)
@@ -0,0 +1,2 @@
+
+
Added: branches/MASSIF2/massif/tests/alloc-fns-A.vgtest
===================================================================
--- branches/MASSIF2/massif/tests/alloc-fns-A.vgtest (rev 0)
+++ branches/MASSIF2/massif/tests/alloc-fns-A.vgtest 2007-09-19 22:36:29 UTC (rev 6868)
@@ -0,0 +1,4 @@
+prog: alloc-fns
+vgopts: --stacks=no --time-unit=B --heap-admin=0
+post: perl ../../massif/ms_print massif.out
+cleanup: rm massif.out
Added: branches/MASSIF2/massif/tests/alloc-fns-B.post.exp
===================================================================
--- branches/MASSIF2/massif/tests/alloc-fns-B.post.exp (rev 0)
+++ branches/MASSIF2/massif/tests/alloc-fns-B.post.exp 2007-09-19 22:36:29 UTC (rev 6868)
@@ -0,0 +1,75 @@
+--------------------------------------------------------------------------------
+Command: ./alloc-fns
+Data file: massif.out
+Options: XXX
+--------------------------------------------------------------------------------
+
+
+900 | @
+ | @
+ | . @
+ | : @
+ | . : @
+ | : : @
+ | : : @
+ | : : : @
+ | : : : @
+ | : : : : @
+ | : : : : @
+ | . : : : : @
+ | : : : : : @
+ | . : : : : : @
+ | : : : : : : @
+ | : : : : : : @
+ | : : : : : : : @
+ | : : : : : : : @
+ | : : : : : : : : @
+ | : : : : : : : : @
+ 0 +-----------------------------------------------------------------------@
+
+
+Number of snapshots: 10
+ Detailed snapshots: [9]
+--------------------------------------------------------------------------------
+ n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
+--------------------------------------------------------------------------------
+ 0 0 0 0 0 0
+ 1 100 100 100 0 0
+ 2 200 200 200 0 0
+ 3 300 300 300 0 0
+ 4 400 400 400 0 0
+ 5 500 500 500 0 0
+ 6 600 600 600 0 0
+ 7 700 700 700 0 0
+ 8 800 800 800 0 0
+ 9 900 900 900 0 0
+100.00% (900B) (heap allocation functions) malloc/new/new[], --alloc-fns, etc.
+->33.33% (300B) 0x80483A3: a3 (alloc-fns.c:4)
+| ->33.33% (300B) 0x80483B9: a2 (alloc-fns.c:5)
+| ->33.33% (300B) 0x80483CF: a1 (alloc-fns.c:6)
+| ->11.11% (100B) 0x8048505: main (alloc-fns.c:25)
+| |
+| ->11.11% (100B) 0x8048512: main (alloc-fns.c:26)
+| |
+| ->11.11% (100B) 0x804851F: main (alloc-fns.c:27)
+|
+->11.11% (100B) 0x8048412: b2 (alloc-fns.c:10)
+| ->11.11% (100B) 0x8048428: b1 (alloc-fns.c:11)
+| ->11.11% (100B) 0x804852C: main (alloc-fns.c:28)
+|
+->11.11% (100B) 0x8048481: c1 (alloc-fns.c:16)
+| ->11.11% (100B) 0x8048539: main (alloc-fns.c:29)
+|
+->11.11% (100B) 0x8048546: main (alloc-fns.c:30)
+|
+->11.11% (100B) 0x80484C4: d2 (alloc-fns.c:20)
+| ->11.11% (100B) 0x8048553: main (alloc-fns.c:31)
+|
+->11.11% (100B) 0x8048560: main (alloc-fns.c:32)
+|
+->11.11% (100B) 0x8048498: d4 (alloc-fns.c:18)
+ ->11.11% (100B) 0x804856D: main (alloc-fns.c:33)
+
+--------------------------------------------------------------------------------
+ n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
+--------------------------------------------------------------------------------
Added: branches/MASSIF2/massif/tests/alloc-fns-B.stderr.exp
===================================================================
--- branches/MASSIF2/massif/tests/alloc-fns-B.stderr.exp (rev 0)
+++ branches/MASSIF2/massif/tests/alloc-fns-B.stderr.exp 2007-09-19 22:36:29 UTC (rev 6868)
@@ -0,0 +1,2 @@
+
+
Added: branches/MASSIF2/massif/tests/alloc-fns-B.vgtest
===================================================================
--- branches/MASSIF2/massif/tests/alloc-fns-B.vgtest (rev 0)
+++ branches/MASSIF2/massif/tests/alloc-fns-B.vgtest 2007-09-19 22:36:29 UTC (rev 6868)
@@ -0,0 +1,6 @@
+prog: alloc-fns
+# We deliberately do d1 and d3 as alloc-fns, so we can test calling into the
+# middle of a chain of functions above and below some alloc-fns.
+vgopts: --stacks=no --time-unit=B --heap-admin=0 --alloc-fn=a4 --alloc-fn=b3 --alloc-fn=c2 --alloc-fn=d1 --alloc-fn=d3
+post: perl ../../massif/ms_print massif.out
+cleanup: rm massif.out
Added: branches/MASSIF2/massif/tests/alloc-fns.c
===================================================================
--- branches/MASSIF2/massif/tests/alloc-fns.c (rev 0)
+++ branches/MASSIF2/massif/tests/alloc-fns.c 2007-09-19 22:36:29 UTC (rev 6868)
@@ -0,0 +1,35 @@
+#include <stdlib.h>
+
+void a4(int n) { malloc(n); }
+void a3(int n) { a4(n); }
+void a2(int n) { a3(n); }
+void a1(int n) { a2(n); }
+
+void b4(int n) { malloc(n); }
+void b3(int n) { b4(n); }
+void b2(int n) { b3(n); }
+void b1(int n) { b2(n); }
+
+void c4(int n) { malloc(n); }
+void c3(int n) { c4(n); }
+void c2(int n) { c3(n); }
+void c1(int n) { c2(n); }
+
+void d4(int n) { malloc(n); }
+void d3(int n) { d4(n); }
+void d2(int n) { d3(n); }
+void d1(int n) { d2(n); }
+
+int main(void)
+{
+ a1(100);
+ a1(100);
+ a1(100);
+ b1(100);
+ c1(100);
+ d1(100);
+ d2(100);
+ d3(100);
+ d4(100);
+ return 0;
+}
Modified: branches/MASSIF2/massif/tests/toobig-allocs.vgtest
===================================================================
--- branches/MASSIF2/massif/tests/toobig-allocs.vgtest 2007-09-19 08:11:49 UTC (rev 6867)
+++ branches/MASSIF2/massif/tests/toobig-allocs.vgtest 2007-09-19 22:36:29 UTC (rev 6868)
@@ -1 +1,2 @@
prog: ../../tests/toobig-allocs
+cleanup: rm massif.out
|
|
From: <js...@ac...> - 2007-09-19 13:06:01
|
Nightly build on minnie ( SuSE 10.0, ppc32 ) started at 2007-09-19 09:00:01 BST Results unchanged from 24 hours ago Checking out valgrind source tree ... done Configuring valgrind ... done Building valgrind ... done Running regression tests ... failed Regression test results follow == 220 tests, 10 stderr failures, 6 stdout failures, 0 posttest failures == memcheck/tests/leak-tree (stderr) memcheck/tests/leakotron (stdout) memcheck/tests/pointer-trace (stderr) memcheck/tests/stack_changes (stderr) memcheck/tests/xml1 (stderr) none/tests/faultstatus (stderr) none/tests/fdleak_cmsg (stderr) none/tests/mremap (stderr) none/tests/mremap2 (stdout) none/tests/ppc32/jm-fp (stdout) none/tests/ppc32/jm-fp (stderr) none/tests/ppc32/round (stdout) none/tests/ppc32/round (stderr) none/tests/ppc32/test_fx (stdout) none/tests/ppc32/test_fx (stderr) none/tests/ppc32/test_gx (stdout) |
|
From: <sv...@va...> - 2007-09-19 08:11:51
|
Author: njn
Date: 2007-09-19 09:11:49 +0100 (Wed, 19 Sep 2007)
New Revision: 6867
Log:
- Remove "other" from sub-threshold lines, it didn't add anything.
- Make ms_print sub-threshold lines accurate by changing them to "in N+
places", (ie. N or more).
- Added two extra threshold tests.
Added:
branches/MASSIF2/massif/tests/thresholds_5_0.post.exp
branches/MASSIF2/massif/tests/thresholds_5_0.stderr.exp
branches/MASSIF2/massif/tests/thresholds_5_0.vgtest
branches/MASSIF2/massif/tests/thresholds_5_10.post.exp
branches/MASSIF2/massif/tests/thresholds_5_10.stderr.exp
branches/MASSIF2/massif/tests/thresholds_5_10.vgtest
Modified:
branches/MASSIF2/massif/ms_main.c
branches/MASSIF2/massif/ms_print
branches/MASSIF2/massif/tests/Makefile.am
branches/MASSIF2/massif/tests/thresholds_0_10.post.exp
branches/MASSIF2/massif/tests/thresholds_10_0.post.exp
branches/MASSIF2/massif/tests/thresholds_10_10.post.exp
Modified: branches/MASSIF2/massif/ms_main.c
===================================================================
--- branches/MASSIF2/massif/ms_main.c 2007-09-19 06:23:14 UTC (rev 6866)
+++ branches/MASSIF2/massif/ms_main.c 2007-09-19 08:11:49 UTC (rev 6867)
@@ -570,7 +570,7 @@
// XXX: taking a full snapshot... could/should just snapshot the significant
// parts. Nb: then the amounts wouldn't add up, unless I represented the
-// "other insignificant places" in XPts. Might be worthwhile -- there can
+// "insignificant places" in XPts. Might be worthwhile -- there can
// be a lot of zero nodes in the XTree...
static XPt* dup_XTree(XPt* xpt, XPt* parent)
{
@@ -1425,7 +1425,7 @@
XPt_revcmp_curr_szB);
// How many children are significant? Also calculate the number of child
- // entries to print -- there may be a need for an "N [other] places" line.
+ // entries to print -- there may be a need for an "in N places" line.
n_sig_children = 0;
while (n_sig_children < xpt->n_children &&
is_significant_XPt(xpt->children[n_sig_children], curr_total_szB)) {
@@ -1457,16 +1457,13 @@
printed_children_szB += child->curr_szB;
}
- // Print the extra "N [other] places" line, if any children were
- // insignificant. If all children were insignificant, we omit the
- // "other".
+ // Print the extra "in N places" line, if any children were insignificant.
if (n_insig_children > 0) {
Char* s = ( n_insig_children == 1 ? "," : "s, all" );
- Char* other = ( n_insig_children == xpt->n_children ? "" : " other" );
SizeT total_insig_children_szB = xpt->curr_szB - printed_children_szB;
perc = make_perc(total_insig_children_szB, curr_total_szB);
- FP("%sn0: %ld in %d%s place%s below massif's threshold (%s)\n",
- depth_str, total_insig_children_szB, n_insig_children, other, s,
+ FP("%sn0: %ld in %d place%s below massif's threshold (%s)\n",
+ depth_str, total_insig_children_szB, n_insig_children, s,
make_perc(clo_threshold, 10000));
}
Modified: branches/MASSIF2/massif/ms_print
===================================================================
--- branches/MASSIF2/massif/ms_print 2007-09-19 06:23:14 UTC (rev 6866)
+++ branches/MASSIF2/massif/ms_print 2007-09-19 08:11:49 UTC (rev 6867)
@@ -265,15 +265,13 @@
if ($is_significant) {
# If this was significant but any children were insignificant, print
- # the "N [other] places" line for them. If all children were
- # insignificant, we omit the "other".
+ # the "in N places" line for them.
if ($print && $n_insig_children > 0) {
$perc = 100 * $total_insig_children_szB / $mem_total_B;
- my $s = ( $n_insig_children == 1 ? "," : "s, all" );
- my $other = ( $n_insig_children == $n_children ? "" : " other" );
- printf("%s->%05.2f%% (%dB) in %d%s place%s below ms_print's threshold (%05.2f%%)\n",
+ printf("%s->%05.2f%% (%dB) in %d+ places, all below "
+ . "ms_print's threshold (%05.2f%%)\n",
$this_prefix2, $perc, $total_insig_children_szB,
- $n_insig_children, $other, $s, $threshold);
+ $n_insig_children, $threshold);
print("$this_prefix2\n");
}
Modified: branches/MASSIF2/massif/tests/Makefile.am
===================================================================
--- branches/MASSIF2/massif/tests/Makefile.am 2007-09-19 06:23:14 UTC (rev 6866)
+++ branches/MASSIF2/massif/tests/Makefile.am 2007-09-19 08:11:49 UTC (rev 6867)
@@ -10,6 +10,8 @@
thresholds_0_0.post.exp thresholds_0_0.stderr.exp thresholds_0_0.vgtest \
thresholds_0_10.post.exp thresholds_0_10.stderr.exp thresholds_0_10.vgtest \
thresholds_10_0.post.exp thresholds_10_0.stderr.exp thresholds_10_0.vgtest \
+ thresholds_5_0.post.exp thresholds_5_0.stderr.exp thresholds_5_0.vgtest \
+ thresholds_5_10.post.exp thresholds_5_10.stderr.exp thresholds_5_10.vgtest \
thresholds_10_10.post.exp thresholds_10_10.stderr.exp thresholds_10_10.vgtest \
toobig-allocs.stderr.exp toobig-allocs.vgtest
Modified: branches/MASSIF2/massif/tests/thresholds_0_10.post.exp
===================================================================
--- branches/MASSIF2/massif/tests/thresholds_0_10.post.exp 2007-09-19 06:23:14 UTC (rev 6866)
+++ branches/MASSIF2/massif/tests/thresholds_0_10.post.exp 2007-09-19 08:11:49 UTC (rev 6867)
@@ -48,14 +48,14 @@
| ->60.00% (6000B) 0x80483D3: a7550 (thresholds.c:38)
| | ->60.00% (6000B) 0x8048448: main (thresholds.c:52)
| |
-| ->06.50% (650B) in 3 other places, all below ms_print's threshold (10.00%)
+| ->06.50% (650B) in 3+ places, all below ms_print's threshold (10.00%)
|
->20.00% (2000B) 0x804846A: main (thresholds.c:55)
|
->13.00% (1300B) 0x80483A4: my_malloc2 (thresholds.c:28)
-| ->13.00% (1300B) in 3 places, all below ms_print's threshold (10.00%)
+| ->13.00% (1300B) in 3+ places, all below ms_print's threshold (10.00%)
|
-->00.50% (50B) in 1 other place, below ms_print's threshold (10.00%)
+->00.50% (50B) in 1+ places, all below ms_print's threshold (10.00%)
--------------------------------------------------------------------------------
n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
Modified: branches/MASSIF2/massif/tests/thresholds_10_0.post.exp
===================================================================
--- branches/MASSIF2/massif/tests/thresholds_10_0.post.exp 2007-09-19 06:23:14 UTC (rev 6866)
+++ branches/MASSIF2/massif/tests/thresholds_10_0.post.exp 2007-09-19 08:11:49 UTC (rev 6867)
@@ -48,14 +48,14 @@
| ->60.00% (6000B) 0x80483D3: a7550 (thresholds.c:38)
| | ->60.00% (6000B) 0x8048448: main (thresholds.c:52)
| |
-| ->06.50% (650B) in 3 other places, all below massif's threshold (10.00%)
+| ->06.50% (650B) in 3 places, all below massif's threshold (10.00%)
|
->20.00% (2000B) 0x804846A: main (thresholds.c:55)
|
->13.00% (1300B) 0x80483A4: my_malloc2 (thresholds.c:28)
| ->13.00% (1300B) in 3 places, all below massif's threshold (10.00%)
|
-->00.50% (50B) in 1 other place, below massif's threshold (10.00%)
+->00.50% (50B) in 1 place, below massif's threshold (10.00%)
--------------------------------------------------------------------------------
n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
Modified: branches/MASSIF2/massif/tests/thresholds_10_10.post.exp
===================================================================
--- branches/MASSIF2/massif/tests/thresholds_10_10.post.exp 2007-09-19 06:23:14 UTC (rev 6866)
+++ branches/MASSIF2/massif/tests/thresholds_10_10.post.exp 2007-09-19 08:11:49 UTC (rev 6867)
@@ -48,14 +48,14 @@
| ->60.00% (6000B) 0x80483D3: a7550 (thresholds.c:38)
| | ->60.00% (6000B) 0x8048448: main (thresholds.c:52)
| |
-| ->06.50% (650B) in 3 other places, all below massif's threshold (10.00%)
+| ->06.50% (650B) in 1+ places, all below ms_print's threshold (10.00%)
|
->20.00% (2000B) 0x804846A: main (thresholds.c:55)
|
->13.00% (1300B) 0x80483A4: my_malloc2 (thresholds.c:28)
| ->13.00% (1300B) in 3 places, all below massif's threshold (10.00%)
|
-->00.50% (50B) in 1 other place, below massif's threshold (10.00%)
+->00.50% (50B) in 1+ places, all below ms_print's threshold (10.00%)
--------------------------------------------------------------------------------
n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
Added: branches/MASSIF2/massif/tests/thresholds_5_0.post.exp
===================================================================
--- branches/MASSIF2/massif/tests/thresholds_5_0.post.exp (rev 0)
+++ branches/MASSIF2/massif/tests/thresholds_5_0.post.exp 2007-09-19 08:11:49 UTC (rev 6867)
@@ -0,0 +1,67 @@
+--------------------------------------------------------------------------------
+Command: ./thresholds
+Data file: massif.out
+Options: XXX
+--------------------------------------------------------------------------------
+
+
+ 10k| @
+ | @
+ | @
+ | @
+ | . @
+ | .. : @
+ | . ::: : @
+ | : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ 0 +-----------------------------------------------------------------------@
+
+
+Number of snapshots: 10
+ Detailed snapshots: [9]
+--------------------------------------------------------------------------------
+ n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
+--------------------------------------------------------------------------------
+ 0 0 0 0 0 0
+ 1 6,000 6,000 6,000 0 0
+ 2 6,900 6,900 6,900 0 0
+ 3 7,200 7,200 7,200 0 0
+ 4 7,300 7,300 7,300 0 0
+ 5 7,400 7,400 7,400 0 0
+ 6 7,450 7,450 7,450 0 0
+ 7 7,950 7,950 7,950 0 0
+ 8 9,950 9,950 9,950 0 0
+ 9 10,000 10,000 10,000 0 0
+100.00% (10000B) (heap allocation functions) malloc/new/new[], --alloc-fns, etc.
+->66.50% (6650B) 0x804838D: my_malloc1 (thresholds.c:23)
+| ->60.00% (6000B) 0x80483D3: a7550 (thresholds.c:38)
+| | ->60.00% (6000B) 0x8048448: main (thresholds.c:52)
+| |
+| ->05.00% (500B) 0x804845A: main (thresholds.c:54)
+| |
+| ->01.50% (150B) in 2 places, all below massif's threshold (05.00%)
+|
+->20.00% (2000B) 0x804846A: main (thresholds.c:55)
+|
+->13.00% (1300B) 0x80483A4: my_malloc2 (thresholds.c:28)
+| ->09.00% (900B) 0x80483E3: a7550 (thresholds.c:39)
+| | ->09.00% (900B) 0x8048448: main (thresholds.c:52)
+| |
+| ->04.00% (400B) in 2 places, all below massif's threshold (05.00%)
+|
+->00.50% (50B) in 1 place, below massif's threshold (05.00%)
+
+--------------------------------------------------------------------------------
+ n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
+--------------------------------------------------------------------------------
Added: branches/MASSIF2/massif/tests/thresholds_5_0.stderr.exp
===================================================================
--- branches/MASSIF2/massif/tests/thresholds_5_0.stderr.exp (rev 0)
+++ branches/MASSIF2/massif/tests/thresholds_5_0.stderr.exp 2007-09-19 08:11:49 UTC (rev 6867)
@@ -0,0 +1,2 @@
+
+
Added: branches/MASSIF2/massif/tests/thresholds_5_0.vgtest
===================================================================
--- branches/MASSIF2/massif/tests/thresholds_5_0.vgtest (rev 0)
+++ branches/MASSIF2/massif/tests/thresholds_5_0.vgtest 2007-09-19 08:11:49 UTC (rev 6867)
@@ -0,0 +1,4 @@
+prog: thresholds
+vgopts: --stacks=no --time-unit=B --heap-admin=0 --threshold=500
+post: perl ../../massif/ms_print massif.out --threshold=0
+cleanup: rm massif.out
Added: branches/MASSIF2/massif/tests/thresholds_5_10.post.exp
===================================================================
--- branches/MASSIF2/massif/tests/thresholds_5_10.post.exp (rev 0)
+++ branches/MASSIF2/massif/tests/thresholds_5_10.post.exp 2007-09-19 08:11:49 UTC (rev 6867)
@@ -0,0 +1,62 @@
+--------------------------------------------------------------------------------
+Command: ./thresholds
+Data file: massif.out
+Options: XXX
+--------------------------------------------------------------------------------
+
+
+ 10k| @
+ | @
+ | @
+ | @
+ | . @
+ | .. : @
+ | . ::: : @
+ | : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ 0 +-----------------------------------------------------------------------@
+
+
+Number of snapshots: 10
+ Detailed snapshots: [9]
+--------------------------------------------------------------------------------
+ n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
+--------------------------------------------------------------------------------
+ 0 0 0 0 0 0
+ 1 6,000 6,000 6,000 0 0
+ 2 6,900 6,900 6,900 0 0
+ 3 7,200 7,200 7,200 0 0
+ 4 7,300 7,300 7,300 0 0
+ 5 7,400 7,400 7,400 0 0
+ 6 7,450 7,450 7,450 0 0
+ 7 7,950 7,950 7,950 0 0
+ 8 9,950 9,950 9,950 0 0
+ 9 10,000 10,000 10,000 0 0
+100.00% (10000B) (heap allocation functions) malloc/new/new[], --alloc-fns, etc.
+->66.50% (6650B) 0x804838D: my_malloc1 (thresholds.c:23)
+| ->60.00% (6000B) 0x80483D3: a7550 (thresholds.c:38)
+| | ->60.00% (6000B) 0x8048448: main (thresholds.c:52)
+| |
+| ->06.50% (650B) in 2+ places, all below ms_print's threshold (10.00%)
+|
+->20.00% (2000B) 0x804846A: main (thresholds.c:55)
+|
+->13.00% (1300B) 0x80483A4: my_malloc2 (thresholds.c:28)
+| ->13.00% (1300B) in 2+ places, all below ms_print's threshold (10.00%)
+|
+->00.50% (50B) in 1+ places, all below ms_print's threshold (10.00%)
+
+--------------------------------------------------------------------------------
+ n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
+--------------------------------------------------------------------------------
Added: branches/MASSIF2/massif/tests/thresholds_5_10.stderr.exp
===================================================================
--- branches/MASSIF2/massif/tests/thresholds_5_10.stderr.exp (rev 0)
+++ branches/MASSIF2/massif/tests/thresholds_5_10.stderr.exp 2007-09-19 08:11:49 UTC (rev 6867)
@@ -0,0 +1,2 @@
+
+
Added: branches/MASSIF2/massif/tests/thresholds_5_10.vgtest
===================================================================
--- branches/MASSIF2/massif/tests/thresholds_5_10.vgtest (rev 0)
+++ branches/MASSIF2/massif/tests/thresholds_5_10.vgtest 2007-09-19 08:11:49 UTC (rev 6867)
@@ -0,0 +1,4 @@
+prog: thresholds
+vgopts: --stacks=no --time-unit=B --heap-admin=0 --threshold=500
+post: perl ../../massif/ms_print massif.out --threshold=10
+cleanup: rm massif.out
|
|
From: <sv...@va...> - 2007-09-19 06:23:14
|
Author: njn
Date: 2007-09-19 07:23:14 +0100 (Wed, 19 Sep 2007)
New Revision: 6866
Log:
- Added four threshold tests. One of them doesn't work yet.
- Improved printing of the detailed snapshots list.
- Added some comments.
- Improved printing of "insignificant" lines in both ms_main.c and ms_print.
Added:
branches/MASSIF2/massif/tests/thresholds.c
branches/MASSIF2/massif/tests/thresholds_0_0.post.exp
branches/MASSIF2/massif/tests/thresholds_0_0.stderr.exp
branches/MASSIF2/massif/tests/thresholds_0_0.vgtest
branches/MASSIF2/massif/tests/thresholds_0_10.post.exp
branches/MASSIF2/massif/tests/thresholds_0_10.stderr.exp
branches/MASSIF2/massif/tests/thresholds_0_10.vgtest
branches/MASSIF2/massif/tests/thresholds_10_0.post.exp
branches/MASSIF2/massif/tests/thresholds_10_0.stderr.exp
branches/MASSIF2/massif/tests/thresholds_10_0.vgtest
branches/MASSIF2/massif/tests/thresholds_10_10.post.exp
branches/MASSIF2/massif/tests/thresholds_10_10.stderr.exp
branches/MASSIF2/massif/tests/thresholds_10_10.vgtest
Modified:
branches/MASSIF2/massif/ms_main.c
branches/MASSIF2/massif/ms_print
branches/MASSIF2/massif/tests/Makefile.am
branches/MASSIF2/massif/tests/basic.post.exp
Modified: branches/MASSIF2/massif/ms_main.c
===================================================================
--- branches/MASSIF2/massif/ms_main.c 2007-09-19 02:00:13 UTC (rev 6865)
+++ branches/MASSIF2/massif/ms_main.c 2007-09-19 06:23:14 UTC (rev 6866)
@@ -30,9 +30,15 @@
//---------------------------------------------------------------------------
// XXX:
//---------------------------------------------------------------------------
-// Next:
+// Todo:
+// - write a good basic test that shows how the tool works, suitable for
+// documentation
+// - get snapshot frequency right after some have been discarded
// - Check MALLOCLIKE_BLOCK works, write regtest
+// - clean up structure of ms_print
+// - work out peak-taking
//
+// Misc:
// - with --heap=no, --heap-admin still counts. should it?
//
// Work out how to take the peak.
@@ -564,7 +570,8 @@
// XXX: taking a full snapshot... could/should just snapshot the significant
// parts. Nb: then the amounts wouldn't add up, unless I represented the
-// "other insignificant places" in XPts.
+// "other insignificant places" in XPts. Might be worthwhile -- there can
+// be a lot of zero nodes in the XTree...
static XPt* dup_XTree(XPt* xpt, XPt* parent)
{
Int i;
@@ -1418,8 +1425,7 @@
XPt_revcmp_curr_szB);
// How many children are significant? Also calculate the number of child
- // entries to print -- there may be a need for an "N other insignificant
- // places" line.
+ // entries to print -- there may be a need for an "N [other] places" line.
n_sig_children = 0;
while (n_sig_children < xpt->n_children &&
is_significant_XPt(xpt->children[n_sig_children], curr_total_szB)) {
@@ -1451,15 +1457,17 @@
printed_children_szB += child->curr_szB;
}
- // Print the extra "N [other] insignificant places" line, if necessary.
- // If there were no significant children, we omit the "other".
+ // Print the extra "N [other] places" line, if any children were
+ // insignificant. If all children were insignificant, we omit the
+ // "other".
if (n_insig_children > 0) {
- Char* s = ( n_insig_children == 1 ? "" : "s" );
- Char* other = ( 0 == n_sig_children ? "" : "other " );
- SizeT unprinted_children_szB = xpt->curr_szB - printed_children_szB;
- perc = make_perc(unprinted_children_szB, curr_total_szB);
- FP("%sn0: %ld in %d %sinsignificant place%s\n",
- depth_str, unprinted_children_szB, n_insig_children, other, s);
+ Char* s = ( n_insig_children == 1 ? "," : "s, all" );
+ Char* other = ( n_insig_children == xpt->n_children ? "" : " other" );
+ SizeT total_insig_children_szB = xpt->curr_szB - printed_children_szB;
+ perc = make_perc(total_insig_children_szB, curr_total_szB);
+ FP("%sn0: %ld in %d%s place%s below massif's threshold (%s)\n",
+ depth_str, total_insig_children_szB, n_insig_children, other, s,
+ make_perc(clo_threshold, 10000));
}
// Unindent.
Modified: branches/MASSIF2/massif/ms_print
===================================================================
--- branches/MASSIF2/massif/ms_print 2007-09-19 02:00:13 UTC (rev 6865)
+++ branches/MASSIF2/massif/ms_print 2007-09-19 06:23:14 UTC (rev 6866)
@@ -32,7 +32,6 @@
# XXX:
# - move graph printing stuff into a separate subroutine
-# - implement --threshold
# - merge read_input_file[12]
#----------------------------------------------------------------------------
@@ -160,6 +159,7 @@
if ($arg =~ /^-v$|^--version$/) {
die("ms_print-$version\n");
+ # XXX: consider making threshold /100, like massif itself
# --threshold=X (tolerates a trailing '%')
} elsif ($arg =~ /^--threshold=([\d\.]+)%?$/) {
$threshold = $1;
@@ -244,7 +244,9 @@
# We precede this node's line with "$this_prefix.$arrow". We precede
# any children of this node with "$this_prefix$child_midfix$arrow".
if ($print && $is_significant) {
- printf("$this_prefix$arrow%05.2f%% (${bytes}B)$details\n", $perc);
+ # Nb: $details might have '%' in it, so don't embed directly in the
+ # format string.
+ printf("$this_prefix$arrow%05.2f%% (${bytes}B)%s\n", $perc, $details);
}
# Now read all the children.
@@ -263,22 +265,21 @@
if ($is_significant) {
# If this was significant but any children were insignificant, print
- # the "N [other] insignificant places" line for them.
- # If all children were insignificant, we omit the "other".
+ # the "N [other] places" line for them. If all children were
+ # insignificant, we omit the "other".
if ($print && $n_insig_children > 0) {
$perc = 100 * $total_insig_children_szB / $mem_total_B;
+ my $s = ( $n_insig_children == 1 ? "," : "s, all" );
my $other = ( $n_insig_children == $n_children ? "" : " other" );
- # XXX: Currently printing "... N insig ..." to distinguish
- # significance judgments made here versus those made in Massif2
- # itself.
- printf("$this_prefix2->%05.2f%% (${total_insig_children_szB}B) ... $n_insig_children$other insig...\n",
- $perc);
+ printf("%s->%05.2f%% (%dB) in %d%s place%s below ms_print's threshold (%05.2f%%)\n",
+ $this_prefix2, $perc, $total_insig_children_szB,
+ $n_insig_children, $other, $s, $threshold);
print("$this_prefix2\n");
}
- # If this node has no children, print an extra empty line.
+ # If this node has no children, print an extra (mostly) empty line.
if ($print && 0 == $n_children) {
- print("$this_prefix\n");
+ print("$this_prefix2\n");
}
return (0, 0);
@@ -367,6 +368,7 @@
#-------------------------------------------------------------------------
# Print header
#-------------------------------------------------------------------------
+ # XXX: print the massif invocation and the ms_print invocation
print($fancy_nl);
print("Command: $cmd\n");
print("Data file: $input_file\n");
@@ -488,13 +490,19 @@
#-------------------------------------------------------------------------
print("\n\n");
print("Number of snapshots: $n_snapshots\n");
- print(" Detailed snapshots:");
+ print(" Detailed snapshots: [");
+ my $first_detailed = 1;
for (my $i = 0; $i < $n_snapshots; $i++) {
if ($is_detaileds[$i]) {
- print(" $i");
+ if ($first_detailed) {
+ printf("$i");
+ $first_detailed = 0;
+ } else {
+ printf(", $i");
+ }
}
}
- print("\n");
+ print("]\n");
}
#-----------------------------------------------------------------------------
@@ -575,6 +583,8 @@
# Depth in the heap tree. '1' means the tree should be printed.
# Then reprint the header.
read_heap_tree(1, "", "", "", $mem_total_B);
+ # XXX: don't print the header if there are no more snapshots!
+ # (see tests/thresholds.c for an example)
print($header);
} else {
die("Line $.: expected 'empty' or '...' after 'heap_tree='\n");
Modified: branches/MASSIF2/massif/tests/Makefile.am
===================================================================
--- branches/MASSIF2/massif/tests/Makefile.am 2007-09-19 02:00:13 UTC (rev 6865)
+++ branches/MASSIF2/massif/tests/Makefile.am 2007-09-19 06:23:14 UTC (rev 6866)
@@ -7,11 +7,16 @@
EXTRA_DIST = $(noinst_SCRIPTS) \
basic.post.exp basic.stderr.exp basic.vgtest \
basic_malloc.stderr.exp basic_malloc.vgtest \
+ thresholds_0_0.post.exp thresholds_0_0.stderr.exp thresholds_0_0.vgtest \
+ thresholds_0_10.post.exp thresholds_0_10.stderr.exp thresholds_0_10.vgtest \
+ thresholds_10_0.post.exp thresholds_10_0.stderr.exp thresholds_10_0.vgtest \
+ thresholds_10_10.post.exp thresholds_10_10.stderr.exp thresholds_10_10.vgtest \
toobig-allocs.stderr.exp toobig-allocs.vgtest
AM_CFLAGS = $(WERROR) -Winline -Wall -Wshadow -g $(AM_FLAG_M3264_PRI)
check_PROGRAMS = \
basic \
- basic_malloc
+ basic_malloc \
+ thresholds
Modified: branches/MASSIF2/massif/tests/basic.post.exp
===================================================================
--- branches/MASSIF2/massif/tests/basic.post.exp 2007-09-19 02:00:13 UTC (rev 6865)
+++ branches/MASSIF2/massif/tests/basic.post.exp 2007-09-19 06:23:14 UTC (rev 6866)
@@ -29,7 +29,7 @@
Number of snapshots: 73
- Detailed snapshots: 9 19 29 39 49 59 69
+ Detailed snapshots: [9, 19, 29, 39, 49, 59, 69]
--------------------------------------------------------------------------------
n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
--------------------------------------------------------------------------------
@@ -45,7 +45,7 @@
9 900 972 900 72 0
92.59% (900B) (heap allocation functions) malloc/new/new[], --alloc-fns, etc.
->92.59% (900B) 0x80483E5: main (basic.c:14)
-
+
--------------------------------------------------------------------------------
n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
--------------------------------------------------------------------------------
@@ -61,7 +61,7 @@
19 1,900 2,052 1,900 152 0
92.59% (1900B) (heap allocation functions) malloc/new/new[], --alloc-fns, etc.
->92.59% (1900B) 0x80483E5: main (basic.c:14)
-
+
--------------------------------------------------------------------------------
n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
--------------------------------------------------------------------------------
@@ -77,7 +77,7 @@
29 2,900 3,132 2,900 232 0
92.59% (2900B) (heap allocation functions) malloc/new/new[], --alloc-fns, etc.
->92.59% (2900B) 0x80483E5: main (basic.c:14)
-
+
--------------------------------------------------------------------------------
n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
--------------------------------------------------------------------------------
@@ -93,7 +93,7 @@
39 3,900 3,564 3,300 264 0
92.59% (3300B) (heap allocation functions) malloc/new/new[], --alloc-fns, etc.
->92.59% (3300B) 0x80483E5: main (basic.c:14)
-
+
--------------------------------------------------------------------------------
n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
--------------------------------------------------------------------------------
@@ -109,7 +109,7 @@
49 4,900 2,484 2,300 184 0
92.59% (2300B) (heap allocation functions) malloc/new/new[], --alloc-fns, etc.
->92.59% (2300B) 0x80483E5: main (basic.c:14)
-
+
--------------------------------------------------------------------------------
n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
--------------------------------------------------------------------------------
@@ -125,7 +125,7 @@
59 5,900 1,404 1,300 104 0
92.59% (1300B) (heap allocation functions) malloc/new/new[], --alloc-fns, etc.
->92.59% (1300B) 0x80483E5: main (basic.c:14)
-
+
--------------------------------------------------------------------------------
n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
--------------------------------------------------------------------------------
@@ -141,7 +141,7 @@
69 6,900 324 300 24 0
92.59% (300B) (heap allocation functions) malloc/new/new[], --alloc-fns, etc.
->92.59% (300B) 0x80483E5: main (basic.c:14)
-
+
--------------------------------------------------------------------------------
n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
--------------------------------------------------------------------------------
Added: branches/MASSIF2/massif/tests/thresholds.c
===================================================================
--- branches/MASSIF2/massif/tests/thresholds.c (rev 0)
+++ branches/MASSIF2/massif/tests/thresholds.c 2007-09-19 06:23:14 UTC (rev 6866)
@@ -0,0 +1,58 @@
+// This test is for testing that the --threshold options in both Massif and
+// ms_print work as they should. A threshold of 10% is a good choice for
+// this file, because in some parts of the tree it renders all children
+// insignificant, and in others parts of the tree it renders only some
+// children insignificant.
+//
+// Also, it's deliberate that the 'malloc(2000)' and 'my_malloc1(500)' calls
+// are in 'main' -- at one point, ms_print was failing to connect some
+// children arrows when a more significant child didn't have any children of
+// its own, eg:
+//
+// |
+// ->20.00% (2000B) 0x804846A: main (thresholds.c:43)
+//
+// ->13.00% (1300B) 0x80483A4: my_malloc2 (thresholds.c:16)
+//
+// (There must be a '|' between the '->'s.)
+
+#include <stdlib.h>
+
+void my_malloc1(int n)
+{
+ malloc(n);
+}
+
+void my_malloc2(int n)
+{
+ malloc(n);
+}
+
+void my_malloc3(int n)
+{
+ malloc(n);
+}
+
+void a7550(void)
+{
+ my_malloc1(6000);
+ my_malloc2( 900);
+}
+
+void a450(void)
+{
+ my_malloc2( 300);
+ my_malloc1( 100);
+ my_malloc2( 100);
+ my_malloc1( 50);
+}
+
+int main(void)
+{
+ a7550();
+ a450();
+ my_malloc1(500);
+ malloc(2000);
+ my_malloc3(50);
+ return 0;
+}
Added: branches/MASSIF2/massif/tests/thresholds_0_0.post.exp
===================================================================
--- branches/MASSIF2/massif/tests/thresholds_0_0.post.exp (rev 0)
+++ branches/MASSIF2/massif/tests/thresholds_0_0.post.exp 2007-09-19 06:23:14 UTC (rev 6866)
@@ -0,0 +1,76 @@
+--------------------------------------------------------------------------------
+Command: ./thresholds
+Data file: massif.out
+Options: XXX
+--------------------------------------------------------------------------------
+
+
+ 10k| @
+ | @
+ | @
+ | @
+ | . @
+ | .. : @
+ | . ::: : @
+ | : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ 0 +-----------------------------------------------------------------------@
+
+
+Number of snapshots: 10
+ Detailed snapshots: [9]
+--------------------------------------------------------------------------------
+ n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
+--------------------------------------------------------------------------------
+ 0 0 0 0 0 0
+ 1 6,000 6,000 6,000 0 0
+ 2 6,900 6,900 6,900 0 0
+ 3 7,200 7,200 7,200 0 0
+ 4 7,300 7,300 7,300 0 0
+ 5 7,400 7,400 7,400 0 0
+ 6 7,450 7,450 7,450 0 0
+ 7 7,950 7,950 7,950 0 0
+ 8 9,950 9,950 9,950 0 0
+ 9 10,000 10,000 10,000 0 0
+100.00% (10000B) (heap allocation functions) malloc/new/new[], --alloc-fns, etc.
+->66.50% (6650B) 0x804838D: my_malloc1 (thresholds.c:23)
+| ->60.00% (6000B) 0x80483D3: a7550 (thresholds.c:38)
+| | ->60.00% (6000B) 0x8048448: main (thresholds.c:52)
+| |
+| ->05.00% (500B) 0x804845A: main (thresholds.c:54)
+| |
+| ->01.00% (100B) 0x8048408: a450 (thresholds.c:45)
+| | ->01.00% (100B) 0x804844D: main (thresholds.c:53)
+| |
+| ->00.50% (50B) 0x8048422: a450 (thresholds.c:47)
+| ->00.50% (50B) 0x804844D: main (thresholds.c:53)
+|
+->20.00% (2000B) 0x804846A: main (thresholds.c:55)
+|
+->13.00% (1300B) 0x80483A4: my_malloc2 (thresholds.c:28)
+| ->09.00% (900B) 0x80483E3: a7550 (thresholds.c:39)
+| | ->09.00% (900B) 0x8048448: main (thresholds.c:52)
+| |
+| ->03.00% (300B) 0x80483FB: a450 (thresholds.c:44)
+| | ->03.00% (300B) 0x804844D: main (thresholds.c:53)
+| |
+| ->01.00% (100B) 0x8048415: a450 (thresholds.c:46)
+| ->01.00% (100B) 0x804844D: main (thresholds.c:53)
+|
+->00.50% (50B) 0x80483BB: my_malloc3 (thresholds.c:33)
+ ->00.50% (50B) 0x8048477: main (thresholds.c:56)
+
+--------------------------------------------------------------------------------
+ n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
+--------------------------------------------------------------------------------
Added: branches/MASSIF2/massif/tests/thresholds_0_0.stderr.exp
===================================================================
--- branches/MASSIF2/massif/tests/thresholds_0_0.stderr.exp (rev 0)
+++ branches/MASSIF2/massif/tests/thresholds_0_0.stderr.exp 2007-09-19 06:23:14 UTC (rev 6866)
@@ -0,0 +1,2 @@
+
+
Added: branches/MASSIF2/massif/tests/thresholds_0_0.vgtest
===================================================================
--- branches/MASSIF2/massif/tests/thresholds_0_0.vgtest (rev 0)
+++ branches/MASSIF2/massif/tests/thresholds_0_0.vgtest 2007-09-19 06:23:14 UTC (rev 6866)
@@ -0,0 +1,4 @@
+prog: thresholds
+vgopts: --stacks=no --time-unit=B --heap-admin=0 --threshold=0
+post: perl ../../massif/ms_print massif.out --threshold=0
+cleanup: rm massif.out
Added: branches/MASSIF2/massif/tests/thresholds_0_10.post.exp
===================================================================
--- branches/MASSIF2/massif/tests/thresholds_0_10.post.exp (rev 0)
+++ branches/MASSIF2/massif/tests/thresholds_0_10.post.exp 2007-09-19 06:23:14 UTC (rev 6866)
@@ -0,0 +1,62 @@
+--------------------------------------------------------------------------------
+Command: ./thresholds
+Data file: massif.out
+Options: XXX
+--------------------------------------------------------------------------------
+
+
+ 10k| @
+ | @
+ | @
+ | @
+ | . @
+ | .. : @
+ | . ::: : @
+ | : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ 0 +-----------------------------------------------------------------------@
+
+
+Number of snapshots: 10
+ Detailed snapshots: [9]
+--------------------------------------------------------------------------------
+ n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
+--------------------------------------------------------------------------------
+ 0 0 0 0 0 0
+ 1 6,000 6,000 6,000 0 0
+ 2 6,900 6,900 6,900 0 0
+ 3 7,200 7,200 7,200 0 0
+ 4 7,300 7,300 7,300 0 0
+ 5 7,400 7,400 7,400 0 0
+ 6 7,450 7,450 7,450 0 0
+ 7 7,950 7,950 7,950 0 0
+ 8 9,950 9,950 9,950 0 0
+ 9 10,000 10,000 10,000 0 0
+100.00% (10000B) (heap allocation functions) malloc/new/new[], --alloc-fns, etc.
+->66.50% (6650B) 0x804838D: my_malloc1 (thresholds.c:23)
+| ->60.00% (6000B) 0x80483D3: a7550 (thresholds.c:38)
+| | ->60.00% (6000B) 0x8048448: main (thresholds.c:52)
+| |
+| ->06.50% (650B) in 3 other places, all below ms_print's threshold (10.00%)
+|
+->20.00% (2000B) 0x804846A: main (thresholds.c:55)
+|
+->13.00% (1300B) 0x80483A4: my_malloc2 (thresholds.c:28)
+| ->13.00% (1300B) in 3 places, all below ms_print's threshold (10.00%)
+|
+->00.50% (50B) in 1 other place, below ms_print's threshold (10.00%)
+
+--------------------------------------------------------------------------------
+ n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
+--------------------------------------------------------------------------------
Added: branches/MASSIF2/massif/tests/thresholds_0_10.stderr.exp
===================================================================
--- branches/MASSIF2/massif/tests/thresholds_0_10.stderr.exp (rev 0)
+++ branches/MASSIF2/massif/tests/thresholds_0_10.stderr.exp 2007-09-19 06:23:14 UTC (rev 6866)
@@ -0,0 +1,2 @@
+
+
Added: branches/MASSIF2/massif/tests/thresholds_0_10.vgtest
===================================================================
--- branches/MASSIF2/massif/tests/thresholds_0_10.vgtest (rev 0)
+++ branches/MASSIF2/massif/tests/thresholds_0_10.vgtest 2007-09-19 06:23:14 UTC (rev 6866)
@@ -0,0 +1,4 @@
+prog: thresholds
+vgopts: --stacks=no --time-unit=B --heap-admin=0 --threshold=0
+post: perl ../../massif/ms_print massif.out --threshold=10
+cleanup: rm massif.out
Added: branches/MASSIF2/massif/tests/thresholds_10_0.post.exp
===================================================================
--- branches/MASSIF2/massif/tests/thresholds_10_0.post.exp (rev 0)
+++ branches/MASSIF2/massif/tests/thresholds_10_0.post.exp 2007-09-19 06:23:14 UTC (rev 6866)
@@ -0,0 +1,62 @@
+--------------------------------------------------------------------------------
+Command: ./thresholds
+Data file: massif.out
+Options: XXX
+--------------------------------------------------------------------------------
+
+
+ 10k| @
+ | @
+ | @
+ | @
+ | . @
+ | .. : @
+ | . ::: : @
+ | : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ 0 +-----------------------------------------------------------------------@
+
+
+Number of snapshots: 10
+ Detailed snapshots: [9]
+--------------------------------------------------------------------------------
+ n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
+--------------------------------------------------------------------------------
+ 0 0 0 0 0 0
+ 1 6,000 6,000 6,000 0 0
+ 2 6,900 6,900 6,900 0 0
+ 3 7,200 7,200 7,200 0 0
+ 4 7,300 7,300 7,300 0 0
+ 5 7,400 7,400 7,400 0 0
+ 6 7,450 7,450 7,450 0 0
+ 7 7,950 7,950 7,950 0 0
+ 8 9,950 9,950 9,950 0 0
+ 9 10,000 10,000 10,000 0 0
+100.00% (10000B) (heap allocation functions) malloc/new/new[], --alloc-fns, etc.
+->66.50% (6650B) 0x804838D: my_malloc1 (thresholds.c:23)
+| ->60.00% (6000B) 0x80483D3: a7550 (thresholds.c:38)
+| | ->60.00% (6000B) 0x8048448: main (thresholds.c:52)
+| |
+| ->06.50% (650B) in 3 other places, all below massif's threshold (10.00%)
+|
+->20.00% (2000B) 0x804846A: main (thresholds.c:55)
+|
+->13.00% (1300B) 0x80483A4: my_malloc2 (thresholds.c:28)
+| ->13.00% (1300B) in 3 places, all below massif's threshold (10.00%)
+|
+->00.50% (50B) in 1 other place, below massif's threshold (10.00%)
+
+--------------------------------------------------------------------------------
+ n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
+--------------------------------------------------------------------------------
Added: branches/MASSIF2/massif/tests/thresholds_10_0.stderr.exp
===================================================================
--- branches/MASSIF2/massif/tests/thresholds_10_0.stderr.exp (rev 0)
+++ branches/MASSIF2/massif/tests/thresholds_10_0.stderr.exp 2007-09-19 06:23:14 UTC (rev 6866)
@@ -0,0 +1,2 @@
+
+
Added: branches/MASSIF2/massif/tests/thresholds_10_0.vgtest
===================================================================
--- branches/MASSIF2/massif/tests/thresholds_10_0.vgtest (rev 0)
+++ branches/MASSIF2/massif/tests/thresholds_10_0.vgtest 2007-09-19 06:23:14 UTC (rev 6866)
@@ -0,0 +1,4 @@
+prog: thresholds
+vgopts: --stacks=no --time-unit=B --heap-admin=0 --threshold=1000
+post: perl ../../massif/ms_print massif.out --threshold=0
+cleanup: rm massif.out
Added: branches/MASSIF2/massif/tests/thresholds_10_10.post.exp
===================================================================
--- branches/MASSIF2/massif/tests/thresholds_10_10.post.exp (rev 0)
+++ branches/MASSIF2/massif/tests/thresholds_10_10.post.exp 2007-09-19 06:23:14 UTC (rev 6866)
@@ -0,0 +1,62 @@
+--------------------------------------------------------------------------------
+Command: ./thresholds
+Data file: massif.out
+Options: XXX
+--------------------------------------------------------------------------------
+
+
+ 10k| @
+ | @
+ | @
+ | @
+ | . @
+ | .. : @
+ | . ::: : @
+ | : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ | : : ::: : @
+ 0 +-----------------------------------------------------------------------@
+
+
+Number of snapshots: 10
+ Detailed snapshots: [9]
+--------------------------------------------------------------------------------
+ n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
+--------------------------------------------------------------------------------
+ 0 0 0 0 0 0
+ 1 6,000 6,000 6,000 0 0
+ 2 6,900 6,900 6,900 0 0
+ 3 7,200 7,200 7,200 0 0
+ 4 7,300 7,300 7,300 0 0
+ 5 7,400 7,400 7,400 0 0
+ 6 7,450 7,450 7,450 0 0
+ 7 7,950 7,950 7,950 0 0
+ 8 9,950 9,950 9,950 0 0
+ 9 10,000 10,000 10,000 0 0
+100.00% (10000B) (heap allocation functions) malloc/new/new[], --alloc-fns, etc.
+->66.50% (6650B) 0x804838D: my_malloc1 (thresholds.c:23)
+| ->60.00% (6000B) 0x80483D3: a7550 (thresholds.c:38)
+| | ->60.00% (6000B) 0x8048448: main (thresholds.c:52)
+| |
+| ->06.50% (650B) in 3 other places, all below massif's threshold (10.00%)
+|
+->20.00% (2000B) 0x804846A: main (thresholds.c:55)
+|
+->13.00% (1300B) 0x80483A4: my_malloc2 (thresholds.c:28)
+| ->13.00% (1300B) in 3 places, all below massif's threshold (10.00%)
+|
+->00.50% (50B) in 1 other place, below massif's threshold (10.00%)
+
+--------------------------------------------------------------------------------
+ n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
+--------------------------------------------------------------------------------
Added: branches/MASSIF2/massif/tests/thresholds_10_10.stderr.exp
===================================================================
--- branches/MASSIF2/massif/tests/thresholds_10_10.stderr.exp (rev 0)
+++ branches/MASSIF2/massif/tests/thresholds_10_10.stderr.exp 2007-09-19 06:23:14 UTC (rev 6866)
@@ -0,0 +1,2 @@
+
+
Added: branches/MASSIF2/massif/tests/thresholds_10_10.vgtest
===================================================================
--- branches/MASSIF2/massif/tests/thresholds_10_10.vgtest (rev 0)
+++ branches/MASSIF2/massif/tests/thresholds_10_10.vgtest 2007-09-19 06:23:14 UTC (rev 6866)
@@ -0,0 +1,4 @@
+prog: thresholds
+vgopts: --stacks=no --time-unit=B --heap-admin=0 --threshold=1000
+post: perl ../../massif/ms_print massif.out --threshold=10
+cleanup: rm massif.out
|
|
From: Tom H. <th...@cy...> - 2007-09-19 02:31:10
|
Nightly build on alvis ( i686, Red Hat 7.3 ) started at 2007-09-19 03:15:02 BST Results unchanged from 24 hours ago Checking out valgrind source tree ... done Configuring valgrind ... done Building valgrind ... done Running regression tests ... failed Regression test results follow == 256 tests, 27 stderr failures, 1 stdout failure, 0 posttest failures == memcheck/tests/addressable (stderr) memcheck/tests/badjump (stderr) memcheck/tests/describe-block (stderr) memcheck/tests/erringfds (stderr) memcheck/tests/leak-0 (stderr) memcheck/tests/leak-cycle (stderr) memcheck/tests/leak-pool-0 (stderr) memcheck/tests/leak-pool-1 (stderr) memcheck/tests/leak-pool-2 (stderr) memcheck/tests/leak-pool-3 (stderr) memcheck/tests/leak-pool-4 (stderr) memcheck/tests/leak-pool-5 (stderr) memcheck/tests/leak-regroot (stderr) memcheck/tests/leak-tree (stderr) memcheck/tests/long_namespace_xml (stderr) memcheck/tests/match-overrun (stderr) memcheck/tests/partial_load_dflt (stderr) memcheck/tests/partial_load_ok (stderr) memcheck/tests/partiallydefinedeq (stderr) memcheck/tests/pointer-trace (stderr) memcheck/tests/sigkill (stderr) memcheck/tests/stack_changes (stderr) memcheck/tests/x86/scalar (stderr) memcheck/tests/x86/scalar_supp (stderr) memcheck/tests/x86/xor-undef-x86 (stderr) memcheck/tests/xml1 (stderr) none/tests/mremap (stderr) none/tests/mremap2 (stdout) |
|
From: Tom H. <th...@cy...> - 2007-09-19 02:23:25
|
Nightly build on dellow ( x86_64, Fedora 7 ) started at 2007-09-19 03:10:04 BST Results unchanged from 24 hours ago Checking out valgrind source tree ... done Configuring valgrind ... done Building valgrind ... done Running regression tests ... failed Regression test results follow == 293 tests, 4 stderr failures, 3 stdout failures, 0 posttest failures == memcheck/tests/pointer-trace (stderr) memcheck/tests/vcpu_fnfns (stdout) memcheck/tests/x86/scalar (stderr) memcheck/tests/xml1 (stderr) none/tests/mremap (stderr) none/tests/mremap2 (stdout) none/tests/pth_detached (stdout) |
|
From: Tom H. <th...@cy...> - 2007-09-19 02:17:21
|
Nightly build on lloyd ( x86_64, Fedora Core 3 ) started at 2007-09-19 03:05:03 BST Results unchanged from 24 hours ago Checking out valgrind source tree ... done Configuring valgrind ... done Building valgrind ... done Running regression tests ... failed Regression test results follow == 293 tests, 6 stderr failures, 1 stdout failure, 0 posttest failures == memcheck/tests/pointer-trace (stderr) memcheck/tests/stack_switch (stderr) memcheck/tests/x86/scalar (stderr) memcheck/tests/x86/scalar_supp (stderr) memcheck/tests/xml1 (stderr) none/tests/mremap (stderr) none/tests/mremap2 (stdout) |
|
From: Tom H. <th...@cy...> - 2007-09-19 02:15:22
|
Nightly build on gill ( x86_64, Fedora Core 2 ) started at 2007-09-19 03:00:04 BST Results unchanged from 24 hours ago Checking out valgrind source tree ... done Configuring valgrind ... done Building valgrind ... done Running regression tests ... failed Regression test results follow == 295 tests, 6 stderr failures, 1 stdout failure, 0 posttest failures == memcheck/tests/pointer-trace (stderr) memcheck/tests/stack_switch (stderr) memcheck/tests/x86/scalar (stderr) memcheck/tests/x86/scalar_supp (stderr) none/tests/fdleak_fcntl (stderr) none/tests/mremap (stderr) none/tests/mremap2 (stdout) |
|
From: <sv...@va...> - 2007-09-19 02:00:13
|
Author: njn
Date: 2007-09-19 03:00:13 +0100 (Wed, 19 Sep 2007)
New Revision: 6865
Log:
wibble
Modified:
branches/MASSIF2/massif/ms_main.c
Modified: branches/MASSIF2/massif/ms_main.c
===================================================================
--- branches/MASSIF2/massif/ms_main.c 2007-09-19 01:46:33 UTC (rev 6864)
+++ branches/MASSIF2/massif/ms_main.c 2007-09-19 02:00:13 UTC (rev 6865)
@@ -1471,9 +1471,9 @@
{
sanity_check_snapshot(snapshot);
- FP("#--------------------------------\n");
+ FP("#-----------\n");
FP("snapshot=%d\n", snapshot_n);
- FP("#--------------------------------\n");
+ FP("#-----------\n");
FP("time=%lu\n", snapshot->time);
FP("mem_total_B=%lu\n", snapshot->total_szB);
FP("mem_heap_B=%lu\n", snapshot->heap_szB);
|
|
From: <sv...@va...> - 2007-09-19 01:46:33
|
Author: njn
Date: 2007-09-19 02:46:33 +0100 (Wed, 19 Sep 2007)
New Revision: 6864
Log:
Compactified ms_print output -- no longer printing the 1-snapshot-per-line
summaries beneath the graph. And squeezed all the info about each snapshot
into a single line, rather than spreading it over 7.
Modified:
branches/MASSIF2/massif/ms_main.c
branches/MASSIF2/massif/ms_print
branches/MASSIF2/massif/tests/basic.post.exp
Modified: branches/MASSIF2/massif/ms_main.c
===================================================================
--- branches/MASSIF2/massif/ms_print 2007-09-18 23:30:07 UTC (rev 6863)
+++ branches/MASSIF2/massif/ms_print 2007-09-19 01:46:33 UTC (rev 6864)
@@ -142,7 +142,8 @@
;
# Used in various places of output.
-my $fancy = '-' x 80 . "\n";
+my $fancy = '-' x 80;
+my $fancy_nl = $fancy . "\n";
#-----------------------------------------------------------------------------
# Argument and option handling
@@ -262,10 +263,15 @@
if ($is_significant) {
# If this was significant but any children were insignificant, print
- # an "insignificant" line for them.
+ # the "N [other] insignificant places" line for them.
+ # If all children were insignificant, we omit the "other".
if ($print && $n_insig_children > 0) {
$perc = 100 * $total_insig_children_szB / $mem_total_B;
- printf("$this_prefix2->%05.2f%% (${total_insig_children_szB}B) ... $n_insig_children insig...\n",
+ my $other = ( $n_insig_children == $n_children ? "" : " other" );
+ # XXX: Currently printing "... N insig ..." to distinguish
+ # significance judgments made here versus those made in Massif2
+ # itself.
+ printf("$this_prefix2->%05.2f%% (${total_insig_children_szB}B) ... $n_insig_children$other insig...\n",
$perc);
print("$this_prefix2\n");
}
@@ -361,11 +367,12 @@
#-------------------------------------------------------------------------
# Print header
#-------------------------------------------------------------------------
- print($fancy);
+ print($fancy_nl);
print("Command: $cmd\n");
print("Data file: $input_file\n");
- print("$desc\n");
- print("\n");
+ print("$desc");
+ print($fancy_nl);
+ print("\n\n");
#-------------------------------------------------------------------------
# Print graph
@@ -477,14 +484,15 @@
}
#-------------------------------------------------------------------------
- # Print graph legend
+ # Print snapshot numbers
#-------------------------------------------------------------------------
- print("\n");
+ print("\n\n");
+ print("Number of snapshots: $n_snapshots\n");
+ print(" Detailed snapshots:");
for (my $i = 0; $i < $n_snapshots; $i++) {
- # XXX: adjust the column widths dynamically
- printf(" snapshot %3d: t = %12s $time_unit, size = %12s bytes\n",
- $snapshot_nums[$i], commify($times[$i]),
- commify($mem_total_Bs[$i]));
+ if ($is_detaileds[$i]) {
+ print(" $i");
+ }
}
print("\n");
}
@@ -517,6 +525,28 @@
($line =~ /^time_unit:\s*(.*)$/) or
die("Line $.: missing 'time_unit' line\n");
+
+ #-------------------------------------------------------------------------
+ # Print snapshot list header
+ #-------------------------------------------------------------------------
+ my $time_column = sprintf("%14s", "time($time_unit)");
+ my $column_format = "%3s %14s %16s %16s %13s %12s\n";
+ my $header =
+ $fancy_nl .
+ sprintf($column_format
+ , "n"
+ , $time_column
+ , "total(B)"
+ , "useful-heap(B)"
+ , "admin-heap(B)"
+ , "stacks(B)"
+ ) .
+ $fancy_nl;
+ print($header);
+
+ #-------------------------------------------------------------------------
+ # Print snapshot list
+ #-------------------------------------------------------------------------
# Read body of input file.
$line = get_line();
while (defined $line) {
@@ -529,21 +559,23 @@
my $mem_stacks_B = get_equals_num_line("mem_stacks_B");
my $heap_tree = get_equals_num_line("heap_tree");
- # Print snapshot header.
- printf("=================================\n");
- printf("== snapshot $snapshot_num (%s $time_unit)\n",
- commify($time));
- printf("=================================\n");
- printf("Total memory usage: %12s bytes\n", commify($mem_total_B));
- printf("Useful heap usage : %12s bytes\n", commify($mem_heap_B));
- printf("Admin heap usage : %12s bytes\n", commify($mem_heap_admin_B));
- printf("Stacks usage : %12s bytes\n", commify($mem_stacks_B));
-
+ # Print snapshot details.
+ printf($column_format,
+ , $snapshot_num
+ , commify($time)
+ , commify($mem_total_B)
+ , commify($mem_heap_B)
+ , commify($mem_heap_admin_B)
+ , commify($mem_stacks_B)
+ );
+
if ($heap_tree eq "empty") {
# do nothing
} elsif ($heap_tree eq "...") {
# Depth in the heap tree. '1' means the tree should be printed.
+ # Then reprint the header.
read_heap_tree(1, "", "", "", $mem_total_B);
+ print($header);
} else {
die("Line $.: expected 'empty' or '...' after 'heap_tree='\n");
}
Modified: branches/MASSIF2/massif/tests/basic.post.exp
===================================================================
--- branches/MASSIF2/massif/tests/basic.post.exp 2007-09-18 23:30:07 UTC (rev 6863)
+++ branches/MASSIF2/massif/tests/basic.post.exp 2007-09-19 01:46:33 UTC (rev 6864)
@@ -2,6 +2,7 @@
Command: ./basic
Data file: massif.out
Options: XXX
+--------------------------------------------------------------------------------
3.9k| :
@@ -26,609 +27,124 @@
|.:::::::@:::::::::@:::::::::@:::::::::@:::::::::@:::::::::@:::::::::@:.
0 +--------@---------@---------@---------@---------@---------@---------@---
- snapshot 0: t = 0 B, size = 0 bytes
- snapshot 1: t = 100 B, size = 108 bytes
- snapshot 2: t = 200 B, size = 216 bytes
- snapshot 3: t = 300 B, size = 324 bytes
- snapshot 4: t = 400 B, size = 432 bytes
- snapshot 5: t = 500 B, size = 540 bytes
- snapshot 6: t = 600 B, size = 648 bytes
- snapshot 7: t = 700 B, size = 756 bytes
- snapshot 8: t = 800 B, size = 864 bytes
- snapshot 9: t = 900 B, size = 972 bytes
- snapshot 10: t = 1,000 B, size = 1,080 bytes
- snapshot 11: t = 1,100 B, size = 1,188 bytes
- snapshot 12: t = 1,200 B, size = 1,296 bytes
- snapshot 13: t = 1,300 B, size = 1,404 bytes
- snapshot 14: t = 1,400 B, size = 1,512 bytes
- snapshot 15: t = 1,500 B, size = 1,620 bytes
- snapshot 16: t = 1,600 B, size = 1,728 bytes
- snapshot 17: t = 1,700 B, size = 1,836 bytes
- snapshot 18: t = 1,800 B, size = 1,944 bytes
- snapshot 19: t = 1,900 B, size = 2,052 bytes
- snapshot 20: t = 2,000 B, size = 2,160 bytes
- snapshot 21: t = 2,100 B, size = 2,268 bytes
- snapshot 22: t = 2,200 B, size = 2,376 bytes
- snapshot 23: t = 2,300 B, size = 2,484 bytes
- snapshot 24: t = 2,400 B, size = 2,592 bytes
- snapshot 25: t = 2,500 B, size = 2,700 bytes
- snapshot 26: t = 2,600 B, size = 2,808 bytes
- snapshot 27: t = 2,700 B, size = 2,916 bytes
- snapshot 28: t = 2,800 B, size = 3,024 bytes
- snapshot 29: t = 2,900 B, size = 3,132 bytes
- snapshot 30: t = 3,000 B, size = 3,240 bytes
- snapshot 31: t = 3,100 B, size = 3,348 bytes
- snapshot 32: t = 3,200 B, size = 3,456 bytes
- snapshot 33: t = 3,300 B, size = 3,564 bytes
- snapshot 34: t = 3,400 B, size = 3,672 bytes
- snapshot 35: t = 3,500 B, size = 3,780 bytes
- snapshot 36: t = 3,600 B, size = 3,888 bytes
- snapshot 37: t = 3,700 B, size = 3,780 bytes
- snapshot 38: t = 3,800 B, size = 3,672 bytes
- snapshot 39: t = 3,900 B, size = 3,564 bytes
- snapshot 40: t = 4,000 B, size = 3,456 bytes
- snapshot 41: t = 4,100 B, size = 3,348 bytes
- snapshot 42: t = 4,200 B, size = 3,240 bytes
- snapshot 43: t = 4,300 B, size = 3,132 bytes
- snapshot 44: t = 4,400 B, size = 3,024 bytes
- snapshot 45: t = 4,500 B, size = 2,916 bytes
- snapshot 46: t = 4,600 B, size = 2,808 bytes
- snapshot 47: t = 4,700 B, size = 2,700 bytes
- snapshot 48: t = 4,800 B, size = 2,592 bytes
- snapshot 49: t = 4,900 B, size = 2,484 bytes
- snapshot 50: t = 5,000 B, size = 2,376 bytes
- snapshot 51: t = 5,100 B, size = 2,268 bytes
- snapshot 52: t = 5,200 B, size = 2,160 bytes
- snapshot 53: t = 5,300 B, size = 2,052 bytes
- snapshot 54: t = 5,400 B, size = 1,944 bytes
- snapshot 55: t = 5,500 B, size = 1,836 bytes
- snapshot 56: t = 5,600 B, size = 1,728 bytes
- snapshot 57: t = 5,700 B, size = 1,620 bytes
- snapshot 58: t = 5,800 B, size = 1,512 bytes
- snapshot 59: t = 5,900 B, size = 1,404 bytes
- snapshot 60: t = 6,000 B, size = 1,296 bytes
- snapshot 61: t = 6,100 B, size = 1,188 bytes
- snapshot 62: t = 6,200 B, size = 1,080 bytes
- snapshot 63: t = 6,300 B, size = 972 bytes
- snapshot 64: t = 6,400 B, size = 864 bytes
- snapshot 65: t = 6,500 B, size = 756 bytes
- snapshot 66: t = 6,600 B, size = 648 bytes
- snapshot 67: t = 6,700 B, size = 540 bytes
- snapshot 68: t = 6,800 B, size = 432 bytes
- snapshot 69: t = 6,900 B, size = 324 bytes
- snapshot 70: t = 7,000 B, size = 216 bytes
- snapshot 71: t = 7,100 B, size = 108 bytes
- snapshot 72: t = 7,200 B, size = 0 bytes
-=================================
-== snapshot 0 (0 B)
-=================================
-Total memory usage: 0 bytes
-Useful heap usage : 0 bytes
-Admin heap usage : 0 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 1 (100 B)
-=================================
-Total memory usage: 108 bytes
-Useful heap usage : 100 bytes
-Admin heap usage : 8 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 2 (200 B)
-=================================
-Total memory usage: 216 bytes
-Useful heap usage : 200 bytes
-Admin heap usage : 16 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 3 (300 B)
-=================================
-Total memory usage: 324 bytes
-Useful heap usage : 300 bytes
-Admin heap usage : 24 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 4 (400 B)
-=================================
-Total memory usage: 432 bytes
-Useful heap usage : 400 bytes
-Admin heap usage : 32 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 5 (500 B)
-=================================
-Total memory usage: 540 bytes
-Useful heap usage : 500 bytes
-Admin heap usage : 40 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 6 (600 B)
-=================================
-Total memory usage: 648 bytes
-Useful heap usage : 600 bytes
-Admin heap usage : 48 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 7 (700 B)
-=================================
-Total memory usage: 756 bytes
-Useful heap usage : 700 bytes
-Admin heap usage : 56 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 8 (800 B)
-=================================
-Total memory usage: 864 bytes
-Useful heap usage : 800 bytes
-Admin heap usage : 64 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 9 (900 B)
-=================================
-Total memory usage: 972 bytes
-Useful heap usage : 900 bytes
-Admin heap usage : 72 bytes
-Stacks usage : 0 bytes
+Number of snapshots: 73
+ Detailed snapshots: 9 19 29 39 49 59 69
+--------------------------------------------------------------------------------
+ n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
+--------------------------------------------------------------------------------
+ 0 0 0 0 0 0
+ 1 100 108 100 8 0
+ 2 200 216 200 16 0
+ 3 300 324 300 24 0
+ 4 400 432 400 32 0
+ 5 500 540 500 40 0
+ 6 600 648 600 48 0
+ 7 700 756 700 56 0
+ 8 800 864 800 64 0
+ 9 900 972 900 72 0
92.59% (900B) (heap allocation functions) malloc/new/new[], --alloc-fns, etc.
->92.59% (900B) 0x80483E5: main (basic.c:14)
-=================================
-== snapshot 10 (1,000 B)
-=================================
-Total memory usage: 1,080 bytes
-Useful heap usage : 1,000 bytes
-Admin heap usage : 80 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 11 (1,100 B)
-=================================
-Total memory usage: 1,188 bytes
-Useful heap usage : 1,100 bytes
-Admin heap usage : 88 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 12 (1,200 B)
-=================================
-Total memory usage: 1,296 bytes
-Useful heap usage : 1,200 bytes
-Admin heap usage : 96 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 13 (1,300 B)
-=================================
-Total memory usage: 1,404 bytes
-Useful heap usage : 1,300 bytes
-Admin heap usage : 104 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 14 (1,400 B)
-=================================
-Total memory usage: 1,512 bytes
-Useful heap usage : 1,400 bytes
-Admin heap usage : 112 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 15 (1,500 B)
-=================================
-Total memory usage: 1,620 bytes
-Useful heap usage : 1,500 bytes
-Admin heap usage : 120 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 16 (1,600 B)
-=================================
-Total memory usage: 1,728 bytes
-Useful heap usage : 1,600 bytes
-Admin heap usage : 128 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 17 (1,700 B)
-=================================
-Total memory usage: 1,836 bytes
-Useful heap usage : 1,700 bytes
-Admin heap usage : 136 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 18 (1,800 B)
-=================================
-Total memory usage: 1,944 bytes
-Useful heap usage : 1,800 bytes
-Admin heap usage : 144 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 19 (1,900 B)
-=================================
-Total memory usage: 2,052 bytes
-Useful heap usage : 1,900 bytes
-Admin heap usage : 152 bytes
-Stacks usage : 0 bytes
+--------------------------------------------------------------------------------
+ n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
+--------------------------------------------------------------------------------
+ 10 1,000 1,080 1,000 80 0
+ 11 1,100 1,188 1,100 88 0
+ 12 1,200 1,296 1,200 96 0
+ 13 1,300 1,404 1,300 104 0
+ 14 1,400 1,512 1,400 112 0
+ 15 1,500 1,620 1,500 120 0
+ 16 1,600 1,728 1,600 128 0
+ 17 1,700 1,836 1,700 136 0
+ 18 1,800 1,944 1,800 144 0
+ 19 1,900 2,052 1,900 152 0
92.59% (1900B) (heap allocation functions) malloc/new/new[], --alloc-fns, etc.
->92.59% (1900B) 0x80483E5: main (basic.c:14)
-=================================
-== snapshot 20 (2,000 B)
-=================================
-Total memory usage: 2,160 bytes
-Useful heap usage : 2,000 bytes
-Admin heap usage : 160 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 21 (2,100 B)
-=================================
-Total memory usage: 2,268 bytes
-Useful heap usage : 2,100 bytes
-Admin heap usage : 168 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 22 (2,200 B)
-=================================
-Total memory usage: 2,376 bytes
-Useful heap usage : 2,200 bytes
-Admin heap usage : 176 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 23 (2,300 B)
-=================================
-Total memory usage: 2,484 bytes
-Useful heap usage : 2,300 bytes
-Admin heap usage : 184 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 24 (2,400 B)
-=================================
-Total memory usage: 2,592 bytes
-Useful heap usage : 2,400 bytes
-Admin heap usage : 192 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 25 (2,500 B)
-=================================
-Total memory usage: 2,700 bytes
-Useful heap usage : 2,500 bytes
-Admin heap usage : 200 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 26 (2,600 B)
-=================================
-Total memory usage: 2,808 bytes
-Useful heap usage : 2,600 bytes
-Admin heap usage : 208 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 27 (2,700 B)
-=================================
-Total memory usage: 2,916 bytes
-Useful heap usage : 2,700 bytes
-Admin heap usage : 216 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 28 (2,800 B)
-=================================
-Total memory usage: 3,024 bytes
-Useful heap usage : 2,800 bytes
-Admin heap usage : 224 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 29 (2,900 B)
-=================================
-Total memory usage: 3,132 bytes
-Useful heap usage : 2,900 bytes
-Admin heap usage : 232 bytes
-Stacks usage : 0 bytes
+--------------------------------------------------------------------------------
+ n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
+--------------------------------------------------------------------------------
+ 20 2,000 2,160 2,000 160 0
+ 21 2,100 2,268 2,100 168 0
+ 22 2,200 2,376 2,200 176 0
+ 23 2,300 2,484 2,300 184 0
+ 24 2,400 2,592 2,400 192 0
+ 25 2,500 2,700 2,500 200 0
+ 26 2,600 2,808 2,600 208 0
+ 27 2,700 2,916 2,700 216 0
+ 28 2,800 3,024 2,800 224 0
+ 29 2,900 3,132 2,900 232 0
92.59% (2900B) (heap allocation functions) malloc/new/new[], --alloc-fns, etc.
->92.59% (2900B) 0x80483E5: main (basic.c:14)
-=================================
-== snapshot 30 (3,000 B)
-=================================
-Total memory usage: 3,240 bytes
-Useful heap usage : 3,000 bytes
-Admin heap usage : 240 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 31 (3,100 B)
-=================================
-Total memory usage: 3,348 bytes
-Useful heap usage : 3,100 bytes
-Admin heap usage : 248 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 32 (3,200 B)
-=================================
-Total memory usage: 3,456 bytes
-Useful heap usage : 3,200 bytes
-Admin heap usage : 256 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 33 (3,300 B)
-=================================
-Total memory usage: 3,564 bytes
-Useful heap usage : 3,300 bytes
-Admin heap usage : 264 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 34 (3,400 B)
-=================================
-Total memory usage: 3,672 bytes
-Useful heap usage : 3,400 bytes
-Admin heap usage : 272 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 35 (3,500 B)
-=================================
-Total memory usage: 3,780 bytes
-Useful heap usage : 3,500 bytes
-Admin heap usage : 280 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 36 (3,600 B)
-=================================
-Total memory usage: 3,888 bytes
-Useful heap usage : 3,600 bytes
-Admin heap usage : 288 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 37 (3,700 B)
-=================================
-Total memory usage: 3,780 bytes
-Useful heap usage : 3,500 bytes
-Admin heap usage : 280 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 38 (3,800 B)
-=================================
-Total memory usage: 3,672 bytes
-Useful heap usage : 3,400 bytes
-Admin heap usage : 272 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 39 (3,900 B)
-=================================
-Total memory usage: 3,564 bytes
-Useful heap usage : 3,300 bytes
-Admin heap usage : 264 bytes
-Stacks usage : 0 bytes
+--------------------------------------------------------------------------------
+ n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
+--------------------------------------------------------------------------------
+ 30 3,000 3,240 3,000 240 0
+ 31 3,100 3,348 3,100 248 0
+ 32 3,200 3,456 3,200 256 0
+ 33 3,300 3,564 3,300 264 0
+ 34 3,400 3,672 3,400 272 0
+ 35 3,500 3,780 3,500 280 0
+ 36 3,600 3,888 3,600 288 0
+ 37 3,700 3,780 3,500 280 0
+ 38 3,800 3,672 3,400 272 0
+ 39 3,900 3,564 3,300 264 0
92.59% (3300B) (heap allocation functions) malloc/new/new[], --alloc-fns, etc.
->92.59% (3300B) 0x80483E5: main (basic.c:14)
-=================================
-== snapshot 40 (4,000 B)
-=================================
-Total memory usage: 3,456 bytes
-Useful heap usage : 3,200 bytes
-Admin heap usage : 256 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 41 (4,100 B)
-=================================
-Total memory usage: 3,348 bytes
-Useful heap usage : 3,100 bytes
-Admin heap usage : 248 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 42 (4,200 B)
-=================================
-Total memory usage: 3,240 bytes
-Useful heap usage : 3,000 bytes
-Admin heap usage : 240 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 43 (4,300 B)
-=================================
-Total memory usage: 3,132 bytes
-Useful heap usage : 2,900 bytes
-Admin heap usage : 232 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 44 (4,400 B)
-=================================
-Total memory usage: 3,024 bytes
-Useful heap usage : 2,800 bytes
-Admin heap usage : 224 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 45 (4,500 B)
-=================================
-Total memory usage: 2,916 bytes
-Useful heap usage : 2,700 bytes
-Admin heap usage : 216 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 46 (4,600 B)
-=================================
-Total memory usage: 2,808 bytes
-Useful heap usage : 2,600 bytes
-Admin heap usage : 208 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 47 (4,700 B)
-=================================
-Total memory usage: 2,700 bytes
-Useful heap usage : 2,500 bytes
-Admin heap usage : 200 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 48 (4,800 B)
-=================================
-Total memory usage: 2,592 bytes
-Useful heap usage : 2,400 bytes
-Admin heap usage : 192 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 49 (4,900 B)
-=================================
-Total memory usage: 2,484 bytes
-Useful heap usage : 2,300 bytes
-Admin heap usage : 184 bytes
-Stacks usage : 0 bytes
+--------------------------------------------------------------------------------
+ n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
+--------------------------------------------------------------------------------
+ 40 4,000 3,456 3,200 256 0
+ 41 4,100 3,348 3,100 248 0
+ 42 4,200 3,240 3,000 240 0
+ 43 4,300 3,132 2,900 232 0
+ 44 4,400 3,024 2,800 224 0
+ 45 4,500 2,916 2,700 216 0
+ 46 4,600 2,808 2,600 208 0
+ 47 4,700 2,700 2,500 200 0
+ 48 4,800 2,592 2,400 192 0
+ 49 4,900 2,484 2,300 184 0
92.59% (2300B) (heap allocation functions) malloc/new/new[], --alloc-fns, etc.
->92.59% (2300B) 0x80483E5: main (basic.c:14)
-=================================
-== snapshot 50 (5,000 B)
-=================================
-Total memory usage: 2,376 bytes
-Useful heap usage : 2,200 bytes
-Admin heap usage : 176 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 51 (5,100 B)
-=================================
-Total memory usage: 2,268 bytes
-Useful heap usage : 2,100 bytes
-Admin heap usage : 168 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 52 (5,200 B)
-=================================
-Total memory usage: 2,160 bytes
-Useful heap usage : 2,000 bytes
-Admin heap usage : 160 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 53 (5,300 B)
-=================================
-Total memory usage: 2,052 bytes
-Useful heap usage : 1,900 bytes
-Admin heap usage : 152 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 54 (5,400 B)
-=================================
-Total memory usage: 1,944 bytes
-Useful heap usage : 1,800 bytes
-Admin heap usage : 144 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 55 (5,500 B)
-=================================
-Total memory usage: 1,836 bytes
-Useful heap usage : 1,700 bytes
-Admin heap usage : 136 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 56 (5,600 B)
-=================================
-Total memory usage: 1,728 bytes
-Useful heap usage : 1,600 bytes
-Admin heap usage : 128 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 57 (5,700 B)
-=================================
-Total memory usage: 1,620 bytes
-Useful heap usage : 1,500 bytes
-Admin heap usage : 120 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 58 (5,800 B)
-=================================
-Total memory usage: 1,512 bytes
-Useful heap usage : 1,400 bytes
-Admin heap usage : 112 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 59 (5,900 B)
-=================================
-Total memory usage: 1,404 bytes
-Useful heap usage : 1,300 bytes
-Admin heap usage : 104 bytes
-Stacks usage : 0 bytes
+--------------------------------------------------------------------------------
+ n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
+--------------------------------------------------------------------------------
+ 50 5,000 2,376 2,200 176 0
+ 51 5,100 2,268 2,100 168 0
+ 52 5,200 2,160 2,000 160 0
+ 53 5,300 2,052 1,900 152 0
+ 54 5,400 1,944 1,800 144 0
+ 55 5,500 1,836 1,700 136 0
+ 56 5,600 1,728 1,600 128 0
+ 57 5,700 1,620 1,500 120 0
+ 58 5,800 1,512 1,400 112 0
+ 59 5,900 1,404 1,300 104 0
92.59% (1300B) (heap allocation functions) malloc/new/new[], --alloc-fns, etc.
->92.59% (1300B) 0x80483E5: main (basic.c:14)
-=================================
-== snapshot 60 (6,000 B)
-=================================
-Total memory usage: 1,296 bytes
-Useful heap usage : 1,200 bytes
-Admin heap usage : 96 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 61 (6,100 B)
-=================================
-Total memory usage: 1,188 bytes
-Useful heap usage : 1,100 bytes
-Admin heap usage : 88 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 62 (6,200 B)
-=================================
-Total memory usage: 1,080 bytes
-Useful heap usage : 1,000 bytes
-Admin heap usage : 80 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 63 (6,300 B)
-=================================
-Total memory usage: 972 bytes
-Useful heap usage : 900 bytes
-Admin heap usage : 72 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 64 (6,400 B)
-=================================
-Total memory usage: 864 bytes
-Useful heap usage : 800 bytes
-Admin heap usage : 64 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 65 (6,500 B)
-=================================
-Total memory usage: 756 bytes
-Useful heap usage : 700 bytes
-Admin heap usage : 56 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 66 (6,600 B)
-=================================
-Total memory usage: 648 bytes
-Useful heap usage : 600 bytes
-Admin heap usage : 48 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 67 (6,700 B)
-=================================
-Total memory usage: 540 bytes
-Useful heap usage : 500 bytes
-Admin heap usage : 40 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 68 (6,800 B)
-=================================
-Total memory usage: 432 bytes
-Useful heap usage : 400 bytes
-Admin heap usage : 32 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 69 (6,900 B)
-=================================
-Total memory usage: 324 bytes
-Useful heap usage : 300 bytes
-Admin heap usage : 24 bytes
-Stacks usage : 0 bytes
+--------------------------------------------------------------------------------
+ n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
+--------------------------------------------------------------------------------
+ 60 6,000 1,296 1,200 96 0
+ 61 6,100 1,188 1,100 88 0
+ 62 6,200 1,080 1,000 80 0
+ 63 6,300 972 900 72 0
+ 64 6,400 864 800 64 0
+ 65 6,500 756 700 56 0
+ 66 6,600 648 600 48 0
+ 67 6,700 540 500 40 0
+ 68 6,800 432 400 32 0
+ 69 6,900 324 300 24 0
92.59% (300B) (heap allocation functions) malloc/new/new[], --alloc-fns, etc.
->92.59% (300B) 0x80483E5: main (basic.c:14)
-=================================
-== snapshot 70 (7,000 B)
-=================================
-Total memory usage: 216 bytes
-Useful heap usage : 200 bytes
-Admin heap usage : 16 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 71 (7,100 B)
-=================================
-Total memory usage: 108 bytes
-Useful heap usage : 100 bytes
-Admin heap usage : 8 bytes
-Stacks usage : 0 bytes
-=================================
-== snapshot 72 (7,200 B)
-=================================
-Total memory usage: 0 bytes
-Useful heap usage : 0 bytes
-Admin heap usage : 0 bytes
-Stacks usage : 0 bytes
+--------------------------------------------------------------------------------
+ n time(B) total(B) useful-heap(B) admin-heap(B) stacks(B)
+--------------------------------------------------------------------------------
+ 70 7,000 216 200 16 0
+ 71 7,100 108 100 8 0
+ 72 7,200 0 0 0 0
|
|
From: <js...@ac...> - 2007-09-19 00:17:32
|
Nightly build on g5 ( SuSE 10.1, ppc970 ) started at 2007-09-19 02:00:01 CEST Results differ from 24 hours ago Checking out valgrind source tree ... done Configuring valgrind ... done Building valgrind ... done Running regression tests ... failed Regression test results follow == 228 tests, 6 stderr failures, 2 stdout failures, 0 posttest failures == memcheck/tests/deep_templates (stdout) memcheck/tests/leak-cycle (stderr) memcheck/tests/leak-tree (stderr) memcheck/tests/pointer-trace (stderr) none/tests/faultstatus (stderr) none/tests/fdleak_cmsg (stderr) none/tests/mremap (stderr) none/tests/mremap2 (stdout) ================================================= == Results from 24 hours ago == ================================================= Checking out valgrind source tree ... done Configuring valgrind ... done Building valgrind ... done Running regression tests ... failed Regression test results follow == 228 tests, 6 stderr failures, 3 stdout failures, 0 posttest failures == memcheck/tests/deep_templates (stdout) memcheck/tests/leak-cycle (stderr) memcheck/tests/leak-tree (stderr) memcheck/tests/pointer-trace (stderr) none/tests/faultstatus (stderr) none/tests/fdleak_cmsg (stderr) none/tests/mremap (stderr) none/tests/mremap2 (stdout) none/tests/res_search (stdout) ================================================= == Difference between 24 hours ago and now == ================================================= *** old.short Wed Sep 19 02:08:58 2007 --- new.short Wed Sep 19 02:17:33 2007 *************** *** 8,10 **** ! == 228 tests, 6 stderr failures, 3 stdout failures, 0 posttest failures == memcheck/tests/deep_templates (stdout) --- 8,10 ---- ! == 228 tests, 6 stderr failures, 2 stdout failures, 0 posttest failures == memcheck/tests/deep_templates (stdout) *************** *** 17,19 **** none/tests/mremap2 (stdout) - none/tests/res_search (stdout) --- 17,18 ---- |
--- branches/MASSIF2/massif/ms_main.c 2007-09-18 23:30:07 UTC (rev 6863)
+++ branches/MASSIF2/massif/ms_main.c 2007-09-19 01:46:33 UTC (rev 6864)
@@ -33,6 +33,8 @@
// Next:
// - Check MALLOCLIKE_BLOCK works, write regtest
//
+// - with --heap=no, --heap-admin still counts. should it?
+//
// Work out how to take the peak.
// - exact peak, or within a certain percentage?
// - include the stack? makes it harder
@@ -1449,10 +1451,11 @@
printed_children_szB += child->curr_szB;
}
// Print the extra "N other insignificant places" line, if necessary.
if (n_insig_children > 0) {
Char* s = ( n_insig_children == 1 ? "" : "s" );
- Char* other = ( 0 == i ? "" : "other " );
+ Char* other = ( 0 == n_sig_children ? "" : "other " );
SizeT unprinted_children_szB = xpt->curr_szB - printed_children_szB;
perc = make_perc(unprinted_children_szB, curr_total_szB);
FP("%sn0: %ld in %d %sinsignificant place%s\n",
@@ -1449,10 +1451,11 @@
printed_children_szB += child->curr_szB;
}
- // Print the extra "N other insignificant places" line, if necessary.
+ // Print the extra "N [other] insignificant places" line, if necessary.
+ // If there were no significant children, we omit the "other".
if (n_insig_children > 0) {
Char* s = ( n_insig_children == 1 ? "" : "s" );
Modified: branches/MASSIF2/massif/ms_print
===================================================================